# ----------------------------------------------------------------------------
# pyglet
# Copyright (c) 2006-2007 Alex Holkner
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions 
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright 
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the pyglet nor the names of its
#    contributors may be used to endorse or promote products
#    derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# ----------------------------------------------------------------------------
'''Wrapper for /usr/include/GL/gl.h

Generated by tools/gengl.py.
Do not modify this file.
'''

__docformat__ = 'restructuredtext'
__version__ = '$Id: gl.py 878 2007-06-09 04:58:51Z Alex.Holkner $'

from ctypes import *
from pyglet.gl.lib import link_GL as _link_function
from pyglet.gl.lib import c_ptrdiff_t

# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by tools/gengl.py.
# Wrapper for /usr/include/GL/gl.h


GLenum = c_uint 	# /usr/include/GL/gl.h:53
GLboolean = c_ubyte 	# /usr/include/GL/gl.h:54
GLbitfield = c_uint 	# /usr/include/GL/gl.h:55
GLbyte = c_char 	# /usr/include/GL/gl.h:56
GLshort = c_short 	# /usr/include/GL/gl.h:57
GLint = c_int 	# /usr/include/GL/gl.h:58
GLsizei = c_int 	# /usr/include/GL/gl.h:59
GLubyte = c_ubyte 	# /usr/include/GL/gl.h:60
GLushort = c_ushort 	# /usr/include/GL/gl.h:61
GLuint = c_uint 	# /usr/include/GL/gl.h:62
GLfloat = c_float 	# /usr/include/GL/gl.h:63
GLclampf = c_float 	# /usr/include/GL/gl.h:64
GLdouble = c_double 	# /usr/include/GL/gl.h:65
GLclampd = c_double 	# /usr/include/GL/gl.h:66
GLvoid = None 	# /usr/include/GL/gl.h:67
GL_VERSION_1_1 = 1 	# /usr/include/GL/gl.h:77
GL_CURRENT_BIT = 1 	# /usr/include/GL/gl.h:80
GL_POINT_BIT = 2 	# /usr/include/GL/gl.h:81
GL_LINE_BIT = 4 	# /usr/include/GL/gl.h:82
GL_POLYGON_BIT = 8 	# /usr/include/GL/gl.h:83
GL_POLYGON_STIPPLE_BIT = 16 	# /usr/include/GL/gl.h:84
GL_PIXEL_MODE_BIT = 32 	# /usr/include/GL/gl.h:85
GL_LIGHTING_BIT = 64 	# /usr/include/GL/gl.h:86
GL_FOG_BIT = 128 	# /usr/include/GL/gl.h:87
GL_DEPTH_BUFFER_BIT = 256 	# /usr/include/GL/gl.h:88
GL_ACCUM_BUFFER_BIT = 512 	# /usr/include/GL/gl.h:89
GL_STENCIL_BUFFER_BIT = 1024 	# /usr/include/GL/gl.h:90
GL_VIEWPORT_BIT = 2048 	# /usr/include/GL/gl.h:91
GL_TRANSFORM_BIT = 4096 	# /usr/include/GL/gl.h:92
GL_ENABLE_BIT = 8192 	# /usr/include/GL/gl.h:93
GL_COLOR_BUFFER_BIT = 16384 	# /usr/include/GL/gl.h:94
GL_HINT_BIT = 32768 	# /usr/include/GL/gl.h:95
GL_EVAL_BIT = 65536 	# /usr/include/GL/gl.h:96
GL_LIST_BIT = 131072 	# /usr/include/GL/gl.h:97
GL_TEXTURE_BIT = 262144 	# /usr/include/GL/gl.h:98
GL_SCISSOR_BIT = 524288 	# /usr/include/GL/gl.h:99
GL_ALL_ATTRIB_BITS = 4294967295 	# /usr/include/GL/gl.h:100
GL_CLIENT_PIXEL_STORE_BIT = 1 	# /usr/include/GL/gl.h:109
GL_CLIENT_VERTEX_ARRAY_BIT = 2 	# /usr/include/GL/gl.h:110
GL_CLIENT_ALL_ATTRIB_BITS = 4294967295 	# /usr/include/GL/gl.h:111
GL_FALSE = 0 	# /usr/include/GL/gl.h:114
GL_TRUE = 1 	# /usr/include/GL/gl.h:115
GL_POINTS = 0 	# /usr/include/GL/gl.h:118
GL_LINES = 1 	# /usr/include/GL/gl.h:119
GL_LINE_LOOP = 2 	# /usr/include/GL/gl.h:120
GL_LINE_STRIP = 3 	# /usr/include/GL/gl.h:121
GL_TRIANGLES = 4 	# /usr/include/GL/gl.h:122
GL_TRIANGLE_STRIP = 5 	# /usr/include/GL/gl.h:123
GL_TRIANGLE_FAN = 6 	# /usr/include/GL/gl.h:124
GL_QUADS = 7 	# /usr/include/GL/gl.h:125
GL_QUAD_STRIP = 8 	# /usr/include/GL/gl.h:126
GL_POLYGON = 9 	# /usr/include/GL/gl.h:127
GL_ACCUM = 256 	# /usr/include/GL/gl.h:130
GL_LOAD = 257 	# /usr/include/GL/gl.h:131
GL_RETURN = 258 	# /usr/include/GL/gl.h:132
GL_MULT = 259 	# /usr/include/GL/gl.h:133
GL_ADD = 260 	# /usr/include/GL/gl.h:134
GL_NEVER = 512 	# /usr/include/GL/gl.h:137
GL_LESS = 513 	# /usr/include/GL/gl.h:138
GL_EQUAL = 514 	# /usr/include/GL/gl.h:139
GL_LEQUAL = 515 	# /usr/include/GL/gl.h:140
GL_GREATER = 516 	# /usr/include/GL/gl.h:141
GL_NOTEQUAL = 517 	# /usr/include/GL/gl.h:142
GL_GEQUAL = 518 	# /usr/include/GL/gl.h:143
GL_ALWAYS = 519 	# /usr/include/GL/gl.h:144
GL_ZERO = 0 	# /usr/include/GL/gl.h:147
GL_ONE = 1 	# /usr/include/GL/gl.h:148
GL_SRC_COLOR = 768 	# /usr/include/GL/gl.h:149
GL_ONE_MINUS_SRC_COLOR = 769 	# /usr/include/GL/gl.h:150
GL_SRC_ALPHA = 770 	# /usr/include/GL/gl.h:151
GL_ONE_MINUS_SRC_ALPHA = 771 	# /usr/include/GL/gl.h:152
GL_DST_ALPHA = 772 	# /usr/include/GL/gl.h:153
GL_ONE_MINUS_DST_ALPHA = 773 	# /usr/include/GL/gl.h:154
GL_DST_COLOR = 774 	# /usr/include/GL/gl.h:159
GL_ONE_MINUS_DST_COLOR = 775 	# /usr/include/GL/gl.h:160
GL_SRC_ALPHA_SATURATE = 776 	# /usr/include/GL/gl.h:161
GL_NONE = 0 	# /usr/include/GL/gl.h:205
GL_FRONT_LEFT = 1024 	# /usr/include/GL/gl.h:206
GL_FRONT_RIGHT = 1025 	# /usr/include/GL/gl.h:207
GL_BACK_LEFT = 1026 	# /usr/include/GL/gl.h:208
GL_BACK_RIGHT = 1027 	# /usr/include/GL/gl.h:209
GL_FRONT = 1028 	# /usr/include/GL/gl.h:210
GL_BACK = 1029 	# /usr/include/GL/gl.h:211
GL_LEFT = 1030 	# /usr/include/GL/gl.h:212
GL_RIGHT = 1031 	# /usr/include/GL/gl.h:213
GL_FRONT_AND_BACK = 1032 	# /usr/include/GL/gl.h:214
GL_AUX0 = 1033 	# /usr/include/GL/gl.h:215
GL_AUX1 = 1034 	# /usr/include/GL/gl.h:216
GL_AUX2 = 1035 	# /usr/include/GL/gl.h:217
GL_AUX3 = 1036 	# /usr/include/GL/gl.h:218
GL_NO_ERROR = 0 	# /usr/include/GL/gl.h:289
GL_INVALID_ENUM = 1280 	# /usr/include/GL/gl.h:290
GL_INVALID_VALUE = 1281 	# /usr/include/GL/gl.h:291
GL_INVALID_OPERATION = 1282 	# /usr/include/GL/gl.h:292
GL_STACK_OVERFLOW = 1283 	# /usr/include/GL/gl.h:293
GL_STACK_UNDERFLOW = 1284 	# /usr/include/GL/gl.h:294
GL_OUT_OF_MEMORY = 1285 	# /usr/include/GL/gl.h:295
GL_TABLE_TOO_LARGE = 32817 	# /usr/include/GL/gl.h:296
GL_2D = 1536 	# /usr/include/GL/gl.h:299
GL_3D = 1537 	# /usr/include/GL/gl.h:300
GL_3D_COLOR = 1538 	# /usr/include/GL/gl.h:301
GL_3D_COLOR_TEXTURE = 1539 	# /usr/include/GL/gl.h:302
GL_4D_COLOR_TEXTURE = 1540 	# /usr/include/GL/gl.h:303
GL_PASS_THROUGH_TOKEN = 1792 	# /usr/include/GL/gl.h:306
GL_POINT_TOKEN = 1793 	# /usr/include/GL/gl.h:307
GL_LINE_TOKEN = 1794 	# /usr/include/GL/gl.h:308
GL_POLYGON_TOKEN = 1795 	# /usr/include/GL/gl.h:309
GL_BITMAP_TOKEN = 1796 	# /usr/include/GL/gl.h:310
GL_DRAW_PIXEL_TOKEN = 1797 	# /usr/include/GL/gl.h:311
GL_COPY_PIXEL_TOKEN = 1798 	# /usr/include/GL/gl.h:312
GL_LINE_RESET_TOKEN = 1799 	# /usr/include/GL/gl.h:313
GL_EXP = 2048 	# /usr/include/GL/gl.h:317
GL_EXP2 = 2049 	# /usr/include/GL/gl.h:318
GL_CW = 2304 	# /usr/include/GL/gl.h:329
GL_CCW = 2305 	# /usr/include/GL/gl.h:330
GL_COEFF = 2560 	# /usr/include/GL/gl.h:333
GL_ORDER = 2561 	# /usr/include/GL/gl.h:334
GL_DOMAIN = 2562 	# /usr/include/GL/gl.h:335
GL_PIXEL_MAP_I_TO_I = 3184 	# /usr/include/GL/gl.h:338
GL_PIXEL_MAP_S_TO_S = 3185 	# /usr/include/GL/gl.h:339
GL_PIXEL_MAP_I_TO_R = 3186 	# /usr/include/GL/gl.h:340
GL_PIXEL_MAP_I_TO_G = 3187 	# /usr/include/GL/gl.h:341
GL_PIXEL_MAP_I_TO_B = 3188 	# /usr/include/GL/gl.h:342
GL_PIXEL_MAP_I_TO_A = 3189 	# /usr/include/GL/gl.h:343
GL_PIXEL_MAP_R_TO_R = 3190 	# /usr/include/GL/gl.h:344
GL_PIXEL_MAP_G_TO_G = 3191 	# /usr/include/GL/gl.h:345
GL_PIXEL_MAP_B_TO_B = 3192 	# /usr/include/GL/gl.h:346
GL_PIXEL_MAP_A_TO_A = 3193 	# /usr/include/GL/gl.h:347
GL_VERTEX_ARRAY_POINTER = 32910 	# /usr/include/GL/gl.h:350
GL_NORMAL_ARRAY_POINTER = 32911 	# /usr/include/GL/gl.h:351
GL_COLOR_ARRAY_POINTER = 32912 	# /usr/include/GL/gl.h:352
GL_INDEX_ARRAY_POINTER = 32913 	# /usr/include/GL/gl.h:353
GL_TEXTURE_COORD_ARRAY_POINTER = 32914 	# /usr/include/GL/gl.h:354
GL_EDGE_FLAG_ARRAY_POINTER = 32915 	# /usr/include/GL/gl.h:355
GL_CURRENT_COLOR = 2816 	# /usr/include/GL/gl.h:358
GL_CURRENT_INDEX = 2817 	# /usr/include/GL/gl.h:359
GL_CURRENT_NORMAL = 2818 	# /usr/include/GL/gl.h:360
GL_CURRENT_TEXTURE_COORDS = 2819 	# /usr/include/GL/gl.h:361
GL_CURRENT_RASTER_COLOR = 2820 	# /usr/include/GL/gl.h:362
GL_CURRENT_RASTER_INDEX = 2821 	# /usr/include/GL/gl.h:363
GL_CURRENT_RASTER_TEXTURE_COORDS = 2822 	# /usr/include/GL/gl.h:364
GL_CURRENT_RASTER_POSITION = 2823 	# /usr/include/GL/gl.h:365
GL_CURRENT_RASTER_POSITION_VALID = 2824 	# /usr/include/GL/gl.h:366
GL_CURRENT_RASTER_DISTANCE = 2825 	# /usr/include/GL/gl.h:367
GL_POINT_SMOOTH = 2832 	# /usr/include/GL/gl.h:368
GL_POINT_SIZE = 2833 	# /usr/include/GL/gl.h:369
GL_SMOOTH_POINT_SIZE_RANGE = 2834 	# /usr/include/GL/gl.h:370
GL_SMOOTH_POINT_SIZE_GRANULARITY = 2835 	# /usr/include/GL/gl.h:371
GL_POINT_SIZE_RANGE = 2834 	# /usr/include/GL/gl.h:372
GL_POINT_SIZE_GRANULARITY = 2835 	# /usr/include/GL/gl.h:373
GL_LINE_SMOOTH = 2848 	# /usr/include/GL/gl.h:374
GL_LINE_WIDTH = 2849 	# /usr/include/GL/gl.h:375
GL_SMOOTH_LINE_WIDTH_RANGE = 2850 	# /usr/include/GL/gl.h:376
GL_SMOOTH_LINE_WIDTH_GRANULARITY = 2851 	# /usr/include/GL/gl.h:377
GL_LINE_WIDTH_RANGE = 2850 	# /usr/include/GL/gl.h:378
GL_LINE_WIDTH_GRANULARITY = 2851 	# /usr/include/GL/gl.h:379
GL_LINE_STIPPLE = 2852 	# /usr/include/GL/gl.h:380
GL_LINE_STIPPLE_PATTERN = 2853 	# /usr/include/GL/gl.h:381
GL_LINE_STIPPLE_REPEAT = 2854 	# /usr/include/GL/gl.h:382
GL_LIST_MODE = 2864 	# /usr/include/GL/gl.h:383
GL_MAX_LIST_NESTING = 2865 	# /usr/include/GL/gl.h:384
GL_LIST_BASE = 2866 	# /usr/include/GL/gl.h:385
GL_LIST_INDEX = 2867 	# /usr/include/GL/gl.h:386
GL_POLYGON_MODE = 2880 	# /usr/include/GL/gl.h:387
GL_POLYGON_SMOOTH = 2881 	# /usr/include/GL/gl.h:388
GL_POLYGON_STIPPLE = 2882 	# /usr/include/GL/gl.h:389
GL_EDGE_FLAG = 2883 	# /usr/include/GL/gl.h:390
GL_CULL_FACE = 2884 	# /usr/include/GL/gl.h:391
GL_CULL_FACE_MODE = 2885 	# /usr/include/GL/gl.h:392
GL_FRONT_FACE = 2886 	# /usr/include/GL/gl.h:393
GL_LIGHTING = 2896 	# /usr/include/GL/gl.h:394
GL_LIGHT_MODEL_LOCAL_VIEWER = 2897 	# /usr/include/GL/gl.h:395
GL_LIGHT_MODEL_TWO_SIDE = 2898 	# /usr/include/GL/gl.h:396
GL_LIGHT_MODEL_AMBIENT = 2899 	# /usr/include/GL/gl.h:397
GL_SHADE_MODEL = 2900 	# /usr/include/GL/gl.h:398
GL_COLOR_MATERIAL_FACE = 2901 	# /usr/include/GL/gl.h:399
GL_COLOR_MATERIAL_PARAMETER = 2902 	# /usr/include/GL/gl.h:400
GL_COLOR_MATERIAL = 2903 	# /usr/include/GL/gl.h:401
GL_FOG = 2912 	# /usr/include/GL/gl.h:402
GL_FOG_INDEX = 2913 	# /usr/include/GL/gl.h:403
GL_FOG_DENSITY = 2914 	# /usr/include/GL/gl.h:404
GL_FOG_START = 2915 	# /usr/include/GL/gl.h:405
GL_FOG_END = 2916 	# /usr/include/GL/gl.h:406
GL_FOG_MODE = 2917 	# /usr/include/GL/gl.h:407
GL_FOG_COLOR = 2918 	# /usr/include/GL/gl.h:408
GL_DEPTH_RANGE = 2928 	# /usr/include/GL/gl.h:409
GL_DEPTH_TEST = 2929 	# /usr/include/GL/gl.h:410
GL_DEPTH_WRITEMASK = 2930 	# /usr/include/GL/gl.h:411
GL_DEPTH_CLEAR_VALUE = 2931 	# /usr/include/GL/gl.h:412
GL_DEPTH_FUNC = 2932 	# /usr/include/GL/gl.h:413
GL_ACCUM_CLEAR_VALUE = 2944 	# /usr/include/GL/gl.h:414
GL_STENCIL_TEST = 2960 	# /usr/include/GL/gl.h:415
GL_STENCIL_CLEAR_VALUE = 2961 	# /usr/include/GL/gl.h:416
GL_STENCIL_FUNC = 2962 	# /usr/include/GL/gl.h:417
GL_STENCIL_VALUE_MASK = 2963 	# /usr/include/GL/gl.h:418
GL_STENCIL_FAIL = 2964 	# /usr/include/GL/gl.h:419
GL_STENCIL_PASS_DEPTH_FAIL = 2965 	# /usr/include/GL/gl.h:420
GL_STENCIL_PASS_DEPTH_PASS = 2966 	# /usr/include/GL/gl.h:421
GL_STENCIL_REF = 2967 	# /usr/include/GL/gl.h:422
GL_STENCIL_WRITEMASK = 2968 	# /usr/include/GL/gl.h:423
GL_MATRIX_MODE = 2976 	# /usr/include/GL/gl.h:424
GL_NORMALIZE = 2977 	# /usr/include/GL/gl.h:425
GL_VIEWPORT = 2978 	# /usr/include/GL/gl.h:426
GL_MODELVIEW_STACK_DEPTH = 2979 	# /usr/include/GL/gl.h:427
GL_PROJECTION_STACK_DEPTH = 2980 	# /usr/include/GL/gl.h:428
GL_TEXTURE_STACK_DEPTH = 2981 	# /usr/include/GL/gl.h:429
GL_MODELVIEW_MATRIX = 2982 	# /usr/include/GL/gl.h:430
GL_PROJECTION_MATRIX = 2983 	# /usr/include/GL/gl.h:431
GL_TEXTURE_MATRIX = 2984 	# /usr/include/GL/gl.h:432
GL_ATTRIB_STACK_DEPTH = 2992 	# /usr/include/GL/gl.h:433
GL_CLIENT_ATTRIB_STACK_DEPTH = 2993 	# /usr/include/GL/gl.h:434
GL_ALPHA_TEST = 3008 	# /usr/include/GL/gl.h:435
GL_ALPHA_TEST_FUNC = 3009 	# /usr/include/GL/gl.h:436
GL_ALPHA_TEST_REF = 3010 	# /usr/include/GL/gl.h:437
GL_DITHER = 3024 	# /usr/include/GL/gl.h:438
GL_BLEND_DST = 3040 	# /usr/include/GL/gl.h:439
GL_BLEND_SRC = 3041 	# /usr/include/GL/gl.h:440
GL_BLEND = 3042 	# /usr/include/GL/gl.h:441
GL_LOGIC_OP_MODE = 3056 	# /usr/include/GL/gl.h:442
GL_INDEX_LOGIC_OP = 3057 	# /usr/include/GL/gl.h:443
GL_LOGIC_OP = 3057 	# /usr/include/GL/gl.h:444
GL_COLOR_LOGIC_OP = 3058 	# /usr/include/GL/gl.h:445
GL_AUX_BUFFERS = 3072 	# /usr/include/GL/gl.h:446
GL_DRAW_BUFFER = 3073 	# /usr/include/GL/gl.h:447
GL_READ_BUFFER = 3074 	# /usr/include/GL/gl.h:448
GL_SCISSOR_BOX = 3088 	# /usr/include/GL/gl.h:449
GL_SCISSOR_TEST = 3089 	# /usr/include/GL/gl.h:450
GL_INDEX_CLEAR_VALUE = 3104 	# /usr/include/GL/gl.h:451
GL_INDEX_WRITEMASK = 3105 	# /usr/include/GL/gl.h:452
GL_COLOR_CLEAR_VALUE = 3106 	# /usr/include/GL/gl.h:453
GL_COLOR_WRITEMASK = 3107 	# /usr/include/GL/gl.h:454
GL_INDEX_MODE = 3120 	# /usr/include/GL/gl.h:455
GL_RGBA_MODE = 3121 	# /usr/include/GL/gl.h:456
GL_DOUBLEBUFFER = 3122 	# /usr/include/GL/gl.h:457
GL_STEREO = 3123 	# /usr/include/GL/gl.h:458
GL_RENDER_MODE = 3136 	# /usr/include/GL/gl.h:459
GL_PERSPECTIVE_CORRECTION_HINT = 3152 	# /usr/include/GL/gl.h:460
GL_POINT_SMOOTH_HINT = 3153 	# /usr/include/GL/gl.h:461
GL_LINE_SMOOTH_HINT = 3154 	# /usr/include/GL/gl.h:462
GL_POLYGON_SMOOTH_HINT = 3155 	# /usr/include/GL/gl.h:463
GL_FOG_HINT = 3156 	# /usr/include/GL/gl.h:464
GL_TEXTURE_GEN_S = 3168 	# /usr/include/GL/gl.h:465
GL_TEXTURE_GEN_T = 3169 	# /usr/include/GL/gl.h:466
GL_TEXTURE_GEN_R = 3170 	# /usr/include/GL/gl.h:467
GL_TEXTURE_GEN_Q = 3171 	# /usr/include/GL/gl.h:468
GL_PIXEL_MAP_I_TO_I_SIZE = 3248 	# /usr/include/GL/gl.h:469
GL_PIXEL_MAP_S_TO_S_SIZE = 3249 	# /usr/include/GL/gl.h:470
GL_PIXEL_MAP_I_TO_R_SIZE = 3250 	# /usr/include/GL/gl.h:471
GL_PIXEL_MAP_I_TO_G_SIZE = 3251 	# /usr/include/GL/gl.h:472
GL_PIXEL_MAP_I_TO_B_SIZE = 3252 	# /usr/include/GL/gl.h:473
GL_PIXEL_MAP_I_TO_A_SIZE = 3253 	# /usr/include/GL/gl.h:474
GL_PIXEL_MAP_R_TO_R_SIZE = 3254 	# /usr/include/GL/gl.h:475
GL_PIXEL_MAP_G_TO_G_SIZE = 3255 	# /usr/include/GL/gl.h:476
GL_PIXEL_MAP_B_TO_B_SIZE = 3256 	# /usr/include/GL/gl.h:477
GL_PIXEL_MAP_A_TO_A_SIZE = 3257 	# /usr/include/GL/gl.h:478
GL_UNPACK_SWAP_BYTES = 3312 	# /usr/include/GL/gl.h:479
GL_UNPACK_LSB_FIRST = 3313 	# /usr/include/GL/gl.h:480
GL_UNPACK_ROW_LENGTH = 3314 	# /usr/include/GL/gl.h:481
GL_UNPACK_SKIP_ROWS = 3315 	# /usr/include/GL/gl.h:482
GL_UNPACK_SKIP_PIXELS = 3316 	# /usr/include/GL/gl.h:483
GL_UNPACK_ALIGNMENT = 3317 	# /usr/include/GL/gl.h:484
GL_PACK_SWAP_BYTES = 3328 	# /usr/include/GL/gl.h:485
GL_PACK_LSB_FIRST = 3329 	# /usr/include/GL/gl.h:486
GL_PACK_ROW_LENGTH = 3330 	# /usr/include/GL/gl.h:487
GL_PACK_SKIP_ROWS = 3331 	# /usr/include/GL/gl.h:488
GL_PACK_SKIP_PIXELS = 3332 	# /usr/include/GL/gl.h:489
GL_PACK_ALIGNMENT = 3333 	# /usr/include/GL/gl.h:490
GL_MAP_COLOR = 3344 	# /usr/include/GL/gl.h:491
GL_MAP_STENCIL = 3345 	# /usr/include/GL/gl.h:492
GL_INDEX_SHIFT = 3346 	# /usr/include/GL/gl.h:493
GL_INDEX_OFFSET = 3347 	# /usr/include/GL/gl.h:494
GL_RED_SCALE = 3348 	# /usr/include/GL/gl.h:495
GL_RED_BIAS = 3349 	# /usr/include/GL/gl.h:496
GL_ZOOM_X = 3350 	# /usr/include/GL/gl.h:497
GL_ZOOM_Y = 3351 	# /usr/include/GL/gl.h:498
GL_GREEN_SCALE = 3352 	# /usr/include/GL/gl.h:499
GL_GREEN_BIAS = 3353 	# /usr/include/GL/gl.h:500
GL_BLUE_SCALE = 3354 	# /usr/include/GL/gl.h:501
GL_BLUE_BIAS = 3355 	# /usr/include/GL/gl.h:502
GL_ALPHA_SCALE = 3356 	# /usr/include/GL/gl.h:503
GL_ALPHA_BIAS = 3357 	# /usr/include/GL/gl.h:504
GL_DEPTH_SCALE = 3358 	# /usr/include/GL/gl.h:505
GL_DEPTH_BIAS = 3359 	# /usr/include/GL/gl.h:506
GL_MAX_EVAL_ORDER = 3376 	# /usr/include/GL/gl.h:507
GL_MAX_LIGHTS = 3377 	# /usr/include/GL/gl.h:508
GL_MAX_CLIP_PLANES = 3378 	# /usr/include/GL/gl.h:509
GL_MAX_TEXTURE_SIZE = 3379 	# /usr/include/GL/gl.h:510
GL_MAX_PIXEL_MAP_TABLE = 3380 	# /usr/include/GL/gl.h:511
GL_MAX_ATTRIB_STACK_DEPTH = 3381 	# /usr/include/GL/gl.h:512
GL_MAX_MODELVIEW_STACK_DEPTH = 3382 	# /usr/include/GL/gl.h:513
GL_MAX_NAME_STACK_DEPTH = 3383 	# /usr/include/GL/gl.h:514
GL_MAX_PROJECTION_STACK_DEPTH = 3384 	# /usr/include/GL/gl.h:515
GL_MAX_TEXTURE_STACK_DEPTH = 3385 	# /usr/include/GL/gl.h:516
GL_MAX_VIEWPORT_DIMS = 3386 	# /usr/include/GL/gl.h:517
GL_MAX_CLIENT_ATTRIB_STACK_DEPTH = 3387 	# /usr/include/GL/gl.h:518
GL_SUBPIXEL_BITS = 3408 	# /usr/include/GL/gl.h:519
GL_INDEX_BITS = 3409 	# /usr/include/GL/gl.h:520
GL_RED_BITS = 3410 	# /usr/include/GL/gl.h:521
GL_GREEN_BITS = 3411 	# /usr/include/GL/gl.h:522
GL_BLUE_BITS = 3412 	# /usr/include/GL/gl.h:523
GL_ALPHA_BITS = 3413 	# /usr/include/GL/gl.h:524
GL_DEPTH_BITS = 3414 	# /usr/include/GL/gl.h:525
GL_STENCIL_BITS = 3415 	# /usr/include/GL/gl.h:526
GL_ACCUM_RED_BITS = 3416 	# /usr/include/GL/gl.h:527
GL_ACCUM_GREEN_BITS = 3417 	# /usr/include/GL/gl.h:528
GL_ACCUM_BLUE_BITS = 3418 	# /usr/include/GL/gl.h:529
GL_ACCUM_ALPHA_BITS = 3419 	# /usr/include/GL/gl.h:530
GL_NAME_STACK_DEPTH = 3440 	# /usr/include/GL/gl.h:531
GL_AUTO_NORMAL = 3456 	# /usr/include/GL/gl.h:532
GL_MAP1_COLOR_4 = 3472 	# /usr/include/GL/gl.h:533
GL_MAP1_INDEX = 3473 	# /usr/include/GL/gl.h:534
GL_MAP1_NORMAL = 3474 	# /usr/include/GL/gl.h:535
GL_MAP1_TEXTURE_COORD_1 = 3475 	# /usr/include/GL/gl.h:536
GL_MAP1_TEXTURE_COORD_2 = 3476 	# /usr/include/GL/gl.h:537
GL_MAP1_TEXTURE_COORD_3 = 3477 	# /usr/include/GL/gl.h:538
GL_MAP1_TEXTURE_COORD_4 = 3478 	# /usr/include/GL/gl.h:539
GL_MAP1_VERTEX_3 = 3479 	# /usr/include/GL/gl.h:540
GL_MAP1_VERTEX_4 = 3480 	# /usr/include/GL/gl.h:541
GL_MAP2_COLOR_4 = 3504 	# /usr/include/GL/gl.h:542
GL_MAP2_INDEX = 3505 	# /usr/include/GL/gl.h:543
GL_MAP2_NORMAL = 3506 	# /usr/include/GL/gl.h:544
GL_MAP2_TEXTURE_COORD_1 = 3507 	# /usr/include/GL/gl.h:545
GL_MAP2_TEXTURE_COORD_2 = 3508 	# /usr/include/GL/gl.h:546
GL_MAP2_TEXTURE_COORD_3 = 3509 	# /usr/include/GL/gl.h:547
GL_MAP2_TEXTURE_COORD_4 = 3510 	# /usr/include/GL/gl.h:548
GL_MAP2_VERTEX_3 = 3511 	# /usr/include/GL/gl.h:549
GL_MAP2_VERTEX_4 = 3512 	# /usr/include/GL/gl.h:550
GL_MAP1_GRID_DOMAIN = 3536 	# /usr/include/GL/gl.h:551
GL_MAP1_GRID_SEGMENTS = 3537 	# /usr/include/GL/gl.h:552
GL_MAP2_GRID_DOMAIN = 3538 	# /usr/include/GL/gl.h:553
GL_MAP2_GRID_SEGMENTS = 3539 	# /usr/include/GL/gl.h:554
GL_TEXTURE_1D = 3552 	# /usr/include/GL/gl.h:555
GL_TEXTURE_2D = 3553 	# /usr/include/GL/gl.h:556
GL_FEEDBACK_BUFFER_POINTER = 3568 	# /usr/include/GL/gl.h:557
GL_FEEDBACK_BUFFER_SIZE = 3569 	# /usr/include/GL/gl.h:558
GL_FEEDBACK_BUFFER_TYPE = 3570 	# /usr/include/GL/gl.h:559
GL_SELECTION_BUFFER_POINTER = 3571 	# /usr/include/GL/gl.h:560
GL_SELECTION_BUFFER_SIZE = 3572 	# /usr/include/GL/gl.h:561
GL_POLYGON_OFFSET_UNITS = 10752 	# /usr/include/GL/gl.h:562
GL_POLYGON_OFFSET_POINT = 10753 	# /usr/include/GL/gl.h:563
GL_POLYGON_OFFSET_LINE = 10754 	# /usr/include/GL/gl.h:564
GL_POLYGON_OFFSET_FILL = 32823 	# /usr/include/GL/gl.h:565
GL_POLYGON_OFFSET_FACTOR = 32824 	# /usr/include/GL/gl.h:566
GL_TEXTURE_BINDING_1D = 32872 	# /usr/include/GL/gl.h:567
GL_TEXTURE_BINDING_2D = 32873 	# /usr/include/GL/gl.h:568
GL_TEXTURE_BINDING_3D = 32874 	# /usr/include/GL/gl.h:569
GL_VERTEX_ARRAY = 32884 	# /usr/include/GL/gl.h:570
GL_NORMAL_ARRAY = 32885 	# /usr/include/GL/gl.h:571
GL_COLOR_ARRAY = 32886 	# /usr/include/GL/gl.h:572
GL_INDEX_ARRAY = 32887 	# /usr/include/GL/gl.h:573
GL_TEXTURE_COORD_ARRAY = 32888 	# /usr/include/GL/gl.h:574
GL_EDGE_FLAG_ARRAY = 32889 	# /usr/include/GL/gl.h:575
GL_VERTEX_ARRAY_SIZE = 32890 	# /usr/include/GL/gl.h:576
GL_VERTEX_ARRAY_TYPE = 32891 	# /usr/include/GL/gl.h:577
GL_VERTEX_ARRAY_STRIDE = 32892 	# /usr/include/GL/gl.h:578
GL_NORMAL_ARRAY_TYPE = 32894 	# /usr/include/GL/gl.h:579
GL_NORMAL_ARRAY_STRIDE = 32895 	# /usr/include/GL/gl.h:580
GL_COLOR_ARRAY_SIZE = 32897 	# /usr/include/GL/gl.h:581
GL_COLOR_ARRAY_TYPE = 32898 	# /usr/include/GL/gl.h:582
GL_COLOR_ARRAY_STRIDE = 32899 	# /usr/include/GL/gl.h:583
GL_INDEX_ARRAY_TYPE = 32901 	# /usr/include/GL/gl.h:584
GL_INDEX_ARRAY_STRIDE = 32902 	# /usr/include/GL/gl.h:585
GL_TEXTURE_COORD_ARRAY_SIZE = 32904 	# /usr/include/GL/gl.h:586
GL_TEXTURE_COORD_ARRAY_TYPE = 32905 	# /usr/include/GL/gl.h:587
GL_TEXTURE_COORD_ARRAY_STRIDE = 32906 	# /usr/include/GL/gl.h:588
GL_EDGE_FLAG_ARRAY_STRIDE = 32908 	# /usr/include/GL/gl.h:589
GL_TEXTURE_WIDTH = 4096 	# /usr/include/GL/gl.h:602
GL_TEXTURE_HEIGHT = 4097 	# /usr/include/GL/gl.h:603
GL_TEXTURE_INTERNAL_FORMAT = 4099 	# /usr/include/GL/gl.h:604
GL_TEXTURE_COMPONENTS = 4099 	# /usr/include/GL/gl.h:605
GL_TEXTURE_BORDER_COLOR = 4100 	# /usr/include/GL/gl.h:606
GL_TEXTURE_BORDER = 4101 	# /usr/include/GL/gl.h:607
GL_TEXTURE_RED_SIZE = 32860 	# /usr/include/GL/gl.h:608
GL_TEXTURE_GREEN_SIZE = 32861 	# /usr/include/GL/gl.h:609
GL_TEXTURE_BLUE_SIZE = 32862 	# /usr/include/GL/gl.h:610
GL_TEXTURE_ALPHA_SIZE = 32863 	# /usr/include/GL/gl.h:611
GL_TEXTURE_LUMINANCE_SIZE = 32864 	# /usr/include/GL/gl.h:612
GL_TEXTURE_INTENSITY_SIZE = 32865 	# /usr/include/GL/gl.h:613
GL_TEXTURE_PRIORITY = 32870 	# /usr/include/GL/gl.h:614
GL_TEXTURE_RESIDENT = 32871 	# /usr/include/GL/gl.h:615
GL_DONT_CARE = 4352 	# /usr/include/GL/gl.h:618
GL_FASTEST = 4353 	# /usr/include/GL/gl.h:619
GL_NICEST = 4354 	# /usr/include/GL/gl.h:620
GL_AMBIENT = 4608 	# /usr/include/GL/gl.h:654
GL_DIFFUSE = 4609 	# /usr/include/GL/gl.h:655
GL_SPECULAR = 4610 	# /usr/include/GL/gl.h:656
GL_POSITION = 4611 	# /usr/include/GL/gl.h:657
GL_SPOT_DIRECTION = 4612 	# /usr/include/GL/gl.h:658
GL_SPOT_EXPONENT = 4613 	# /usr/include/GL/gl.h:659
GL_SPOT_CUTOFF = 4614 	# /usr/include/GL/gl.h:660
GL_CONSTANT_ATTENUATION = 4615 	# /usr/include/GL/gl.h:661
GL_LINEAR_ATTENUATION = 4616 	# /usr/include/GL/gl.h:662
GL_QUADRATIC_ATTENUATION = 4617 	# /usr/include/GL/gl.h:663
GL_COMPILE = 4864 	# /usr/include/GL/gl.h:666
GL_COMPILE_AND_EXECUTE = 4865 	# /usr/include/GL/gl.h:667
GL_BYTE = 5120 	# /usr/include/GL/gl.h:670
GL_UNSIGNED_BYTE = 5121 	# /usr/include/GL/gl.h:671
GL_SHORT = 5122 	# /usr/include/GL/gl.h:672
GL_UNSIGNED_SHORT = 5123 	# /usr/include/GL/gl.h:673
GL_INT = 5124 	# /usr/include/GL/gl.h:674
GL_UNSIGNED_INT = 5125 	# /usr/include/GL/gl.h:675
GL_FLOAT = 5126 	# /usr/include/GL/gl.h:676
GL_2_BYTES = 5127 	# /usr/include/GL/gl.h:677
GL_3_BYTES = 5128 	# /usr/include/GL/gl.h:678
GL_4_BYTES = 5129 	# /usr/include/GL/gl.h:679
GL_DOUBLE = 5130 	# /usr/include/GL/gl.h:680
GL_DOUBLE_EXT = 5130 	# /usr/include/GL/gl.h:681
GL_CLEAR = 5376 	# /usr/include/GL/gl.h:696
GL_AND = 5377 	# /usr/include/GL/gl.h:697
GL_AND_REVERSE = 5378 	# /usr/include/GL/gl.h:698
GL_COPY = 5379 	# /usr/include/GL/gl.h:699
GL_AND_INVERTED = 5380 	# /usr/include/GL/gl.h:700
GL_NOOP = 5381 	# /usr/include/GL/gl.h:701
GL_XOR = 5382 	# /usr/include/GL/gl.h:702
GL_OR = 5383 	# /usr/include/GL/gl.h:703
GL_NOR = 5384 	# /usr/include/GL/gl.h:704
GL_EQUIV = 5385 	# /usr/include/GL/gl.h:705
GL_INVERT = 5386 	# /usr/include/GL/gl.h:706
GL_OR_REVERSE = 5387 	# /usr/include/GL/gl.h:707
GL_COPY_INVERTED = 5388 	# /usr/include/GL/gl.h:708
GL_OR_INVERTED = 5389 	# /usr/include/GL/gl.h:709
GL_NAND = 5390 	# /usr/include/GL/gl.h:710
GL_SET = 5391 	# /usr/include/GL/gl.h:711
GL_EMISSION = 5632 	# /usr/include/GL/gl.h:739
GL_SHININESS = 5633 	# /usr/include/GL/gl.h:740
GL_AMBIENT_AND_DIFFUSE = 5634 	# /usr/include/GL/gl.h:741
GL_COLOR_INDEXES = 5635 	# /usr/include/GL/gl.h:742
GL_MODELVIEW = 5888 	# /usr/include/GL/gl.h:748
GL_PROJECTION = 5889 	# /usr/include/GL/gl.h:749
GL_TEXTURE = 5890 	# /usr/include/GL/gl.h:750
GL_COLOR = 6144 	# /usr/include/GL/gl.h:769
GL_DEPTH = 6145 	# /usr/include/GL/gl.h:770
GL_STENCIL = 6146 	# /usr/include/GL/gl.h:771
GL_COLOR_INDEX = 6400 	# /usr/include/GL/gl.h:774
GL_STENCIL_INDEX = 6401 	# /usr/include/GL/gl.h:775
GL_DEPTH_COMPONENT = 6402 	# /usr/include/GL/gl.h:776
GL_RED = 6403 	# /usr/include/GL/gl.h:777
GL_GREEN = 6404 	# /usr/include/GL/gl.h:778
GL_BLUE = 6405 	# /usr/include/GL/gl.h:779
GL_ALPHA = 6406 	# /usr/include/GL/gl.h:780
GL_RGB = 6407 	# /usr/include/GL/gl.h:781
GL_RGBA = 6408 	# /usr/include/GL/gl.h:782
GL_LUMINANCE = 6409 	# /usr/include/GL/gl.h:783
GL_LUMINANCE_ALPHA = 6410 	# /usr/include/GL/gl.h:784
GL_BITMAP = 6656 	# /usr/include/GL/gl.h:830
GL_POINT = 6912 	# /usr/include/GL/gl.h:845
GL_LINE = 6913 	# /usr/include/GL/gl.h:846
GL_FILL = 6914 	# /usr/include/GL/gl.h:847
GL_RENDER = 7168 	# /usr/include/GL/gl.h:864
GL_FEEDBACK = 7169 	# /usr/include/GL/gl.h:865
GL_SELECT = 7170 	# /usr/include/GL/gl.h:866
GL_FLAT = 7424 	# /usr/include/GL/gl.h:869
GL_SMOOTH = 7425 	# /usr/include/GL/gl.h:870
GL_KEEP = 7680 	# /usr/include/GL/gl.h:884
GL_REPLACE = 7681 	# /usr/include/GL/gl.h:885
GL_INCR = 7682 	# /usr/include/GL/gl.h:886
GL_DECR = 7683 	# /usr/include/GL/gl.h:887
GL_VENDOR = 7936 	# /usr/include/GL/gl.h:891
GL_RENDERER = 7937 	# /usr/include/GL/gl.h:892
GL_VERSION = 7938 	# /usr/include/GL/gl.h:893
GL_EXTENSIONS = 7939 	# /usr/include/GL/gl.h:894
GL_S = 8192 	# /usr/include/GL/gl.h:903
GL_T = 8193 	# /usr/include/GL/gl.h:904
GL_R = 8194 	# /usr/include/GL/gl.h:905
GL_Q = 8195 	# /usr/include/GL/gl.h:906
GL_MODULATE = 8448 	# /usr/include/GL/gl.h:909
GL_DECAL = 8449 	# /usr/include/GL/gl.h:910
GL_TEXTURE_ENV_MODE = 8704 	# /usr/include/GL/gl.h:916
GL_TEXTURE_ENV_COLOR = 8705 	# /usr/include/GL/gl.h:917
GL_TEXTURE_ENV = 8960 	# /usr/include/GL/gl.h:920
GL_EYE_LINEAR = 9216 	# /usr/include/GL/gl.h:923
GL_OBJECT_LINEAR = 9217 	# /usr/include/GL/gl.h:924
GL_SPHERE_MAP = 9218 	# /usr/include/GL/gl.h:925
GL_TEXTURE_GEN_MODE = 9472 	# /usr/include/GL/gl.h:928
GL_OBJECT_PLANE = 9473 	# /usr/include/GL/gl.h:929
GL_EYE_PLANE = 9474 	# /usr/include/GL/gl.h:930
GL_NEAREST = 9728 	# /usr/include/GL/gl.h:933
GL_LINEAR = 9729 	# /usr/include/GL/gl.h:934
GL_NEAREST_MIPMAP_NEAREST = 9984 	# /usr/include/GL/gl.h:939
GL_LINEAR_MIPMAP_NEAREST = 9985 	# /usr/include/GL/gl.h:940
GL_NEAREST_MIPMAP_LINEAR = 9986 	# /usr/include/GL/gl.h:941
GL_LINEAR_MIPMAP_LINEAR = 9987 	# /usr/include/GL/gl.h:942
GL_TEXTURE_MAG_FILTER = 10240 	# /usr/include/GL/gl.h:945
GL_TEXTURE_MIN_FILTER = 10241 	# /usr/include/GL/gl.h:946
GL_TEXTURE_WRAP_S = 10242 	# /usr/include/GL/gl.h:947
GL_TEXTURE_WRAP_T = 10243 	# /usr/include/GL/gl.h:948
GL_PROXY_TEXTURE_1D = 32867 	# /usr/include/GL/gl.h:955
GL_PROXY_TEXTURE_2D = 32868 	# /usr/include/GL/gl.h:956
GL_CLAMP = 10496 	# /usr/include/GL/gl.h:959
GL_REPEAT = 10497 	# /usr/include/GL/gl.h:960
GL_R3_G3_B2 = 10768 	# /usr/include/GL/gl.h:963
GL_ALPHA4 = 32827 	# /usr/include/GL/gl.h:964
GL_ALPHA8 = 32828 	# /usr/include/GL/gl.h:965
GL_ALPHA12 = 32829 	# /usr/include/GL/gl.h:966
GL_ALPHA16 = 32830 	# /usr/include/GL/gl.h:967
GL_LUMINANCE4 = 32831 	# /usr/include/GL/gl.h:968
GL_LUMINANCE8 = 32832 	# /usr/include/GL/gl.h:969
GL_LUMINANCE12 = 32833 	# /usr/include/GL/gl.h:970
GL_LUMINANCE16 = 32834 	# /usr/include/GL/gl.h:971
GL_LUMINANCE4_ALPHA4 = 32835 	# /usr/include/GL/gl.h:972
GL_LUMINANCE6_ALPHA2 = 32836 	# /usr/include/GL/gl.h:973
GL_LUMINANCE8_ALPHA8 = 32837 	# /usr/include/GL/gl.h:974
GL_LUMINANCE12_ALPHA4 = 32838 	# /usr/include/GL/gl.h:975
GL_LUMINANCE12_ALPHA12 = 32839 	# /usr/include/GL/gl.h:976
GL_LUMINANCE16_ALPHA16 = 32840 	# /usr/include/GL/gl.h:977
GL_INTENSITY = 32841 	# /usr/include/GL/gl.h:978
GL_INTENSITY4 = 32842 	# /usr/include/GL/gl.h:979
GL_INTENSITY8 = 32843 	# /usr/include/GL/gl.h:980
GL_INTENSITY12 = 32844 	# /usr/include/GL/gl.h:981
GL_INTENSITY16 = 32845 	# /usr/include/GL/gl.h:982
GL_RGB4 = 32847 	# /usr/include/GL/gl.h:983
GL_RGB5 = 32848 	# /usr/include/GL/gl.h:984
GL_RGB8 = 32849 	# /usr/include/GL/gl.h:985
GL_RGB10 = 32850 	# /usr/include/GL/gl.h:986
GL_RGB12 = 32851 	# /usr/include/GL/gl.h:987
GL_RGB16 = 32852 	# /usr/include/GL/gl.h:988
GL_RGBA2 = 32853 	# /usr/include/GL/gl.h:989
GL_RGBA4 = 32854 	# /usr/include/GL/gl.h:990
GL_RGB5_A1 = 32855 	# /usr/include/GL/gl.h:991
GL_RGBA8 = 32856 	# /usr/include/GL/gl.h:992
GL_RGB10_A2 = 32857 	# /usr/include/GL/gl.h:993
GL_RGBA12 = 32858 	# /usr/include/GL/gl.h:994
GL_RGBA16 = 32859 	# /usr/include/GL/gl.h:995
GL_V2F = 10784 	# /usr/include/GL/gl.h:998
GL_V3F = 10785 	# /usr/include/GL/gl.h:999
GL_C4UB_V2F = 10786 	# /usr/include/GL/gl.h:1000
GL_C4UB_V3F = 10787 	# /usr/include/GL/gl.h:1001
GL_C3F_V3F = 10788 	# /usr/include/GL/gl.h:1002
GL_N3F_V3F = 10789 	# /usr/include/GL/gl.h:1003
GL_C4F_N3F_V3F = 10790 	# /usr/include/GL/gl.h:1004
GL_T2F_V3F = 10791 	# /usr/include/GL/gl.h:1005
GL_T4F_V4F = 10792 	# /usr/include/GL/gl.h:1006
GL_T2F_C4UB_V3F = 10793 	# /usr/include/GL/gl.h:1007
GL_T2F_C3F_V3F = 10794 	# /usr/include/GL/gl.h:1008
GL_T2F_N3F_V3F = 10795 	# /usr/include/GL/gl.h:1009
GL_T2F_C4F_N3F_V3F = 10796 	# /usr/include/GL/gl.h:1010
GL_T4F_C4F_N3F_V4F = 10797 	# /usr/include/GL/gl.h:1011
GL_CLIP_PLANE0 = 12288 	# /usr/include/GL/gl.h:1020
GL_CLIP_PLANE1 = 12289 	# /usr/include/GL/gl.h:1021
GL_CLIP_PLANE2 = 12290 	# /usr/include/GL/gl.h:1022
GL_CLIP_PLANE3 = 12291 	# /usr/include/GL/gl.h:1023
GL_CLIP_PLANE4 = 12292 	# /usr/include/GL/gl.h:1024
GL_CLIP_PLANE5 = 12293 	# /usr/include/GL/gl.h:1025
GL_LIGHT0 = 16384 	# /usr/include/GL/gl.h:1028
GL_LIGHT1 = 16385 	# /usr/include/GL/gl.h:1029
GL_LIGHT2 = 16386 	# /usr/include/GL/gl.h:1030
GL_LIGHT3 = 16387 	# /usr/include/GL/gl.h:1031
GL_LIGHT4 = 16388 	# /usr/include/GL/gl.h:1032
GL_LIGHT5 = 16389 	# /usr/include/GL/gl.h:1033
GL_LIGHT6 = 16390 	# /usr/include/GL/gl.h:1034
GL_LIGHT7 = 16391 	# /usr/include/GL/gl.h:1035
GL_ABGR_EXT = 32768 	# /usr/include/GL/gl.h:1038
GL_FUNC_SUBTRACT_EXT = 32778 	# /usr/include/GL/gl.h:1041
GL_FUNC_REVERSE_SUBTRACT_EXT = 32779 	# /usr/include/GL/gl.h:1042
GL_UNSIGNED_BYTE_3_3_2_EXT = 32818 	# /usr/include/GL/gl.h:1045
GL_UNSIGNED_SHORT_4_4_4_4_EXT = 32819 	# /usr/include/GL/gl.h:1046
GL_UNSIGNED_SHORT_5_5_5_1_EXT = 32820 	# /usr/include/GL/gl.h:1047
GL_UNSIGNED_INT_8_8_8_8_EXT = 32821 	# /usr/include/GL/gl.h:1048
GL_UNSIGNED_INT_10_10_10_2_EXT = 32822 	# /usr/include/GL/gl.h:1049
GL_PACK_SKIP_IMAGES = 32875 	# /usr/include/GL/gl.h:1052
GL_PACK_IMAGE_HEIGHT = 32876 	# /usr/include/GL/gl.h:1053
GL_UNPACK_SKIP_IMAGES = 32877 	# /usr/include/GL/gl.h:1054
GL_UNPACK_IMAGE_HEIGHT = 32878 	# /usr/include/GL/gl.h:1055
GL_TEXTURE_3D = 32879 	# /usr/include/GL/gl.h:1056
GL_PROXY_TEXTURE_3D = 32880 	# /usr/include/GL/gl.h:1057
GL_TEXTURE_DEPTH = 32881 	# /usr/include/GL/gl.h:1058
GL_TEXTURE_WRAP_R = 32882 	# /usr/include/GL/gl.h:1059
GL_MAX_3D_TEXTURE_SIZE = 32883 	# /usr/include/GL/gl.h:1060
GL_BGR = 32992 	# /usr/include/GL/gl.h:1061
GL_BGRA = 32993 	# /usr/include/GL/gl.h:1062
GL_UNSIGNED_BYTE_3_3_2 = 32818 	# /usr/include/GL/gl.h:1063
GL_UNSIGNED_BYTE_2_3_3_REV = 33634 	# /usr/include/GL/gl.h:1064
GL_UNSIGNED_SHORT_5_6_5 = 33635 	# /usr/include/GL/gl.h:1065
GL_UNSIGNED_SHORT_5_6_5_REV = 33636 	# /usr/include/GL/gl.h:1066
GL_UNSIGNED_SHORT_4_4_4_4 = 32819 	# /usr/include/GL/gl.h:1067
GL_UNSIGNED_SHORT_4_4_4_4_REV = 33637 	# /usr/include/GL/gl.h:1068
GL_UNSIGNED_SHORT_5_5_5_1 = 32820 	# /usr/include/GL/gl.h:1069
GL_UNSIGNED_SHORT_1_5_5_5_REV = 33638 	# /usr/include/GL/gl.h:1070
GL_UNSIGNED_INT_8_8_8_8 = 32821 	# /usr/include/GL/gl.h:1071
GL_UNSIGNED_INT_8_8_8_8_REV = 33639 	# /usr/include/GL/gl.h:1072
GL_UNSIGNED_INT_10_10_10_2 = 32822 	# /usr/include/GL/gl.h:1073
GL_UNSIGNED_INT_2_10_10_10_REV = 33640 	# /usr/include/GL/gl.h:1074
GL_RESCALE_NORMAL = 32826 	# /usr/include/GL/gl.h:1075
GL_LIGHT_MODEL_COLOR_CONTROL = 33272 	# /usr/include/GL/gl.h:1076
GL_SINGLE_COLOR = 33273 	# /usr/include/GL/gl.h:1077
GL_SEPARATE_SPECULAR_COLOR = 33274 	# /usr/include/GL/gl.h:1078
GL_CLAMP_TO_EDGE = 33071 	# /usr/include/GL/gl.h:1079
GL_TEXTURE_MIN_LOD = 33082 	# /usr/include/GL/gl.h:1080
GL_TEXTURE_MAX_LOD = 33083 	# /usr/include/GL/gl.h:1081
GL_TEXTURE_BASE_LEVEL = 33084 	# /usr/include/GL/gl.h:1082
GL_TEXTURE_MAX_LEVEL = 33085 	# /usr/include/GL/gl.h:1083
GL_MAX_ELEMENTS_VERTICES = 33000 	# /usr/include/GL/gl.h:1084
GL_MAX_ELEMENTS_INDICES = 33001 	# /usr/include/GL/gl.h:1085
GL_ALIASED_POINT_SIZE_RANGE = 33901 	# /usr/include/GL/gl.h:1086
GL_ALIASED_LINE_WIDTH_RANGE = 33902 	# /usr/include/GL/gl.h:1087
GL_ACTIVE_TEXTURE = 34016 	# /usr/include/GL/gl.h:1090
GL_CLIENT_ACTIVE_TEXTURE = 34017 	# /usr/include/GL/gl.h:1091
GL_MAX_TEXTURE_UNITS = 34018 	# /usr/include/GL/gl.h:1092
GL_TEXTURE0 = 33984 	# /usr/include/GL/gl.h:1093
GL_TEXTURE1 = 33985 	# /usr/include/GL/gl.h:1094
GL_TEXTURE2 = 33986 	# /usr/include/GL/gl.h:1095
GL_TEXTURE3 = 33987 	# /usr/include/GL/gl.h:1096
GL_TEXTURE4 = 33988 	# /usr/include/GL/gl.h:1097
GL_TEXTURE5 = 33989 	# /usr/include/GL/gl.h:1098
GL_TEXTURE6 = 33990 	# /usr/include/GL/gl.h:1099
GL_TEXTURE7 = 33991 	# /usr/include/GL/gl.h:1100
GL_TEXTURE8 = 33992 	# /usr/include/GL/gl.h:1101
GL_TEXTURE9 = 33993 	# /usr/include/GL/gl.h:1102
GL_TEXTURE10 = 33994 	# /usr/include/GL/gl.h:1103
GL_TEXTURE11 = 33995 	# /usr/include/GL/gl.h:1104
GL_TEXTURE12 = 33996 	# /usr/include/GL/gl.h:1105
GL_TEXTURE13 = 33997 	# /usr/include/GL/gl.h:1106
GL_TEXTURE14 = 33998 	# /usr/include/GL/gl.h:1107
GL_TEXTURE15 = 33999 	# /usr/include/GL/gl.h:1108
GL_TEXTURE16 = 34000 	# /usr/include/GL/gl.h:1109
GL_TEXTURE17 = 34001 	# /usr/include/GL/gl.h:1110
GL_TEXTURE18 = 34002 	# /usr/include/GL/gl.h:1111
GL_TEXTURE19 = 34003 	# /usr/include/GL/gl.h:1112
GL_TEXTURE20 = 34004 	# /usr/include/GL/gl.h:1113
GL_TEXTURE21 = 34005 	# /usr/include/GL/gl.h:1114
GL_TEXTURE22 = 34006 	# /usr/include/GL/gl.h:1115
GL_TEXTURE23 = 34007 	# /usr/include/GL/gl.h:1116
GL_TEXTURE24 = 34008 	# /usr/include/GL/gl.h:1117
GL_TEXTURE25 = 34009 	# /usr/include/GL/gl.h:1118
GL_TEXTURE26 = 34010 	# /usr/include/GL/gl.h:1119
GL_TEXTURE27 = 34011 	# /usr/include/GL/gl.h:1120
GL_TEXTURE28 = 34012 	# /usr/include/GL/gl.h:1121
GL_TEXTURE29 = 34013 	# /usr/include/GL/gl.h:1122
GL_TEXTURE30 = 34014 	# /usr/include/GL/gl.h:1123
GL_TEXTURE31 = 34015 	# /usr/include/GL/gl.h:1124
GL_NORMAL_MAP = 34065 	# /usr/include/GL/gl.h:1125
GL_REFLECTION_MAP = 34066 	# /usr/include/GL/gl.h:1126
GL_TEXTURE_CUBE_MAP = 34067 	# /usr/include/GL/gl.h:1127
GL_TEXTURE_BINDING_CUBE_MAP = 34068 	# /usr/include/GL/gl.h:1128
GL_TEXTURE_CUBE_MAP_POSITIVE_X = 34069 	# /usr/include/GL/gl.h:1129
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = 34070 	# /usr/include/GL/gl.h:1130
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = 34071 	# /usr/include/GL/gl.h:1131
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = 34072 	# /usr/include/GL/gl.h:1132
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = 34073 	# /usr/include/GL/gl.h:1133
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = 34074 	# /usr/include/GL/gl.h:1134
GL_PROXY_TEXTURE_CUBE_MAP = 34075 	# /usr/include/GL/gl.h:1135
GL_MAX_CUBE_MAP_TEXTURE_SIZE = 34076 	# /usr/include/GL/gl.h:1136
GL_COMBINE = 34160 	# /usr/include/GL/gl.h:1137
GL_COMBINE_RGB = 34161 	# /usr/include/GL/gl.h:1138
GL_COMBINE_ALPHA = 34162 	# /usr/include/GL/gl.h:1139
GL_RGB_SCALE = 34163 	# /usr/include/GL/gl.h:1140
GL_ADD_SIGNED = 34164 	# /usr/include/GL/gl.h:1141
GL_INTERPOLATE = 34165 	# /usr/include/GL/gl.h:1142
GL_CONSTANT = 34166 	# /usr/include/GL/gl.h:1143
GL_PRIMARY_COLOR = 34167 	# /usr/include/GL/gl.h:1144
GL_PREVIOUS = 34168 	# /usr/include/GL/gl.h:1145
GL_SOURCE0_RGB = 34176 	# /usr/include/GL/gl.h:1146
GL_SOURCE1_RGB = 34177 	# /usr/include/GL/gl.h:1147
GL_SOURCE2_RGB = 34178 	# /usr/include/GL/gl.h:1148
GL_SOURCE0_ALPHA = 34184 	# /usr/include/GL/gl.h:1149
GL_SOURCE1_ALPHA = 34185 	# /usr/include/GL/gl.h:1150
GL_SOURCE2_ALPHA = 34186 	# /usr/include/GL/gl.h:1151
GL_OPERAND0_RGB = 34192 	# /usr/include/GL/gl.h:1152
GL_OPERAND1_RGB = 34193 	# /usr/include/GL/gl.h:1153
GL_OPERAND2_RGB = 34194 	# /usr/include/GL/gl.h:1154
GL_OPERAND0_ALPHA = 34200 	# /usr/include/GL/gl.h:1155
GL_OPERAND1_ALPHA = 34201 	# /usr/include/GL/gl.h:1156
GL_OPERAND2_ALPHA = 34202 	# /usr/include/GL/gl.h:1157
GL_SUBTRACT = 34023 	# /usr/include/GL/gl.h:1158
GL_TRANSPOSE_MODELVIEW_MATRIX = 34019 	# /usr/include/GL/gl.h:1159
GL_TRANSPOSE_PROJECTION_MATRIX = 34020 	# /usr/include/GL/gl.h:1160
GL_TRANSPOSE_TEXTURE_MATRIX = 34021 	# /usr/include/GL/gl.h:1161
GL_TRANSPOSE_COLOR_MATRIX = 34022 	# /usr/include/GL/gl.h:1162
GL_COMPRESSED_ALPHA = 34025 	# /usr/include/GL/gl.h:1163
GL_COMPRESSED_LUMINANCE = 34026 	# /usr/include/GL/gl.h:1164
GL_COMPRESSED_LUMINANCE_ALPHA = 34027 	# /usr/include/GL/gl.h:1165
GL_COMPRESSED_INTENSITY = 34028 	# /usr/include/GL/gl.h:1166
GL_COMPRESSED_RGB = 34029 	# /usr/include/GL/gl.h:1167
GL_COMPRESSED_RGBA = 34030 	# /usr/include/GL/gl.h:1168
GL_TEXTURE_COMPRESSION_HINT = 34031 	# /usr/include/GL/gl.h:1169
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = 34464 	# /usr/include/GL/gl.h:1170
GL_TEXTURE_COMPRESSED = 34465 	# /usr/include/GL/gl.h:1171
GL_NUM_COMPRESSED_TEXTURE_FORMATS = 34466 	# /usr/include/GL/gl.h:1172
GL_COMPRESSED_TEXTURE_FORMATS = 34467 	# /usr/include/GL/gl.h:1173
GL_DOT3_RGB = 34478 	# /usr/include/GL/gl.h:1174
GL_DOT3_RGBA = 34479 	# /usr/include/GL/gl.h:1175
GL_CLAMP_TO_BORDER = 33069 	# /usr/include/GL/gl.h:1176
GL_MULTISAMPLE = 32925 	# /usr/include/GL/gl.h:1177
GL_SAMPLE_ALPHA_TO_COVERAGE = 32926 	# /usr/include/GL/gl.h:1178
GL_SAMPLE_ALPHA_TO_ONE = 32927 	# /usr/include/GL/gl.h:1179
GL_SAMPLE_COVERAGE = 32928 	# /usr/include/GL/gl.h:1180
GL_SAMPLE_BUFFERS = 32936 	# /usr/include/GL/gl.h:1181
GL_SAMPLES = 32937 	# /usr/include/GL/gl.h:1182
GL_SAMPLE_COVERAGE_VALUE = 32938 	# /usr/include/GL/gl.h:1183
GL_SAMPLE_COVERAGE_INVERT = 32939 	# /usr/include/GL/gl.h:1184
GL_MULTISAMPLE_BIT = 536870912 	# /usr/include/GL/gl.h:1185
GL_VERTEX_ARRAY_EXT = 32884 	# /usr/include/GL/gl.h:1188
GL_NORMAL_ARRAY_EXT = 32885 	# /usr/include/GL/gl.h:1189
GL_COLOR_ARRAY_EXT = 32886 	# /usr/include/GL/gl.h:1190
GL_INDEX_ARRAY_EXT = 32887 	# /usr/include/GL/gl.h:1191
GL_TEXTURE_COORD_ARRAY_EXT = 32888 	# /usr/include/GL/gl.h:1192
GL_EDGE_FLAG_ARRAY_EXT = 32889 	# /usr/include/GL/gl.h:1193
GL_VERTEX_ARRAY_SIZE_EXT = 32890 	# /usr/include/GL/gl.h:1194
GL_VERTEX_ARRAY_TYPE_EXT = 32891 	# /usr/include/GL/gl.h:1195
GL_VERTEX_ARRAY_STRIDE_EXT = 32892 	# /usr/include/GL/gl.h:1196
GL_VERTEX_ARRAY_COUNT_EXT = 32893 	# /usr/include/GL/gl.h:1197
GL_NORMAL_ARRAY_TYPE_EXT = 32894 	# /usr/include/GL/gl.h:1198
GL_NORMAL_ARRAY_STRIDE_EXT = 32895 	# /usr/include/GL/gl.h:1199
GL_NORMAL_ARRAY_COUNT_EXT = 32896 	# /usr/include/GL/gl.h:1200
GL_COLOR_ARRAY_SIZE_EXT = 32897 	# /usr/include/GL/gl.h:1201
GL_COLOR_ARRAY_TYPE_EXT = 32898 	# /usr/include/GL/gl.h:1202
GL_COLOR_ARRAY_STRIDE_EXT = 32899 	# /usr/include/GL/gl.h:1203
GL_COLOR_ARRAY_COUNT_EXT = 32900 	# /usr/include/GL/gl.h:1204
GL_INDEX_ARRAY_TYPE_EXT = 32901 	# /usr/include/GL/gl.h:1205
GL_INDEX_ARRAY_STRIDE_EXT = 32902 	# /usr/include/GL/gl.h:1206
GL_INDEX_ARRAY_COUNT_EXT = 32903 	# /usr/include/GL/gl.h:1207
GL_TEXTURE_COORD_ARRAY_SIZE_EXT = 32904 	# /usr/include/GL/gl.h:1208
GL_TEXTURE_COORD_ARRAY_TYPE_EXT = 32905 	# /usr/include/GL/gl.h:1209
GL_TEXTURE_COORD_ARRAY_STRIDE_EXT = 32906 	# /usr/include/GL/gl.h:1210
GL_TEXTURE_COORD_ARRAY_COUNT_EXT = 32907 	# /usr/include/GL/gl.h:1211
GL_EDGE_FLAG_ARRAY_STRIDE_EXT = 32908 	# /usr/include/GL/gl.h:1212
GL_EDGE_FLAG_ARRAY_COUNT_EXT = 32909 	# /usr/include/GL/gl.h:1213
GL_VERTEX_ARRAY_POINTER_EXT = 32910 	# /usr/include/GL/gl.h:1214
GL_NORMAL_ARRAY_POINTER_EXT = 32911 	# /usr/include/GL/gl.h:1215
GL_COLOR_ARRAY_POINTER_EXT = 32912 	# /usr/include/GL/gl.h:1216
GL_INDEX_ARRAY_POINTER_EXT = 32913 	# /usr/include/GL/gl.h:1217
GL_TEXTURE_COORD_ARRAY_POINTER_EXT = 32914 	# /usr/include/GL/gl.h:1218
GL_EDGE_FLAG_ARRAY_POINTER_EXT = 32915 	# /usr/include/GL/gl.h:1219
GL_TEXTURE_MIN_LOD_SGIS = 33082 	# /usr/include/GL/gl.h:1222
GL_TEXTURE_MAX_LOD_SGIS = 33083 	# /usr/include/GL/gl.h:1223
GL_TEXTURE_BASE_LEVEL_SGIS = 33084 	# /usr/include/GL/gl.h:1224
GL_TEXTURE_MAX_LEVEL_SGIS = 33085 	# /usr/include/GL/gl.h:1225
GL_SHARED_TEXTURE_PALETTE_EXT = 33275 	# /usr/include/GL/gl.h:1228
GL_RESCALE_NORMAL_EXT = 32826 	# /usr/include/GL/gl.h:1231
GL_TEXTURE_COMPARE_SGIX = 33178 	# /usr/include/GL/gl.h:1234
GL_TEXTURE_COMPARE_OPERATOR_SGIX = 33179 	# /usr/include/GL/gl.h:1235
GL_TEXTURE_LEQUAL_R_SGIX = 33180 	# /usr/include/GL/gl.h:1236
GL_TEXTURE_GEQUAL_R_SGIX = 33181 	# /usr/include/GL/gl.h:1237
GL_DEPTH_COMPONENT16_SGIX = 33189 	# /usr/include/GL/gl.h:1240
GL_DEPTH_COMPONENT24_SGIX = 33190 	# /usr/include/GL/gl.h:1241
GL_DEPTH_COMPONENT32_SGIX = 33191 	# /usr/include/GL/gl.h:1242
GL_GENERATE_MIPMAP_SGIS = 33169 	# /usr/include/GL/gl.h:1245
GL_GENERATE_MIPMAP_HINT_SGIS = 33170 	# /usr/include/GL/gl.h:1246
GL_POINT_SIZE_MIN = 33062 	# /usr/include/GL/gl.h:1249
GL_POINT_SIZE_MAX = 33063 	# /usr/include/GL/gl.h:1250
GL_POINT_FADE_THRESHOLD_SIZE = 33064 	# /usr/include/GL/gl.h:1251
GL_POINT_DISTANCE_ATTENUATION = 33065 	# /usr/include/GL/gl.h:1252
GL_FOG_COORDINATE_SOURCE = 33872 	# /usr/include/GL/gl.h:1253
GL_FOG_COORDINATE = 33873 	# /usr/include/GL/gl.h:1254
GL_FRAGMENT_DEPTH = 33874 	# /usr/include/GL/gl.h:1255
GL_CURRENT_FOG_COORDINATE = 33875 	# /usr/include/GL/gl.h:1256
GL_FOG_COORDINATE_ARRAY_TYPE = 33876 	# /usr/include/GL/gl.h:1257
GL_FOG_COORDINATE_ARRAY_STRIDE = 33877 	# /usr/include/GL/gl.h:1258
GL_FOG_COORDINATE_ARRAY_POINTER = 33878 	# /usr/include/GL/gl.h:1259
GL_FOG_COORDINATE_ARRAY = 33879 	# /usr/include/GL/gl.h:1260
GL_COLOR_SUM = 33880 	# /usr/include/GL/gl.h:1261
GL_CURRENT_SECONDARY_COLOR = 33881 	# /usr/include/GL/gl.h:1262
GL_SECONDARY_COLOR_ARRAY_SIZE = 33882 	# /usr/include/GL/gl.h:1263
GL_SECONDARY_COLOR_ARRAY_TYPE = 33883 	# /usr/include/GL/gl.h:1264
GL_SECONDARY_COLOR_ARRAY_STRIDE = 33884 	# /usr/include/GL/gl.h:1265
GL_SECONDARY_COLOR_ARRAY_POINTER = 33885 	# /usr/include/GL/gl.h:1266
GL_SECONDARY_COLOR_ARRAY = 33886 	# /usr/include/GL/gl.h:1267
GL_INCR_WRAP = 34055 	# /usr/include/GL/gl.h:1268
GL_DECR_WRAP = 34056 	# /usr/include/GL/gl.h:1269
GL_MAX_TEXTURE_LOD_BIAS = 34045 	# /usr/include/GL/gl.h:1270
GL_TEXTURE_FILTER_CONTROL = 34048 	# /usr/include/GL/gl.h:1271
GL_TEXTURE_LOD_BIAS = 34049 	# /usr/include/GL/gl.h:1272
GL_GENERATE_MIPMAP = 33169 	# /usr/include/GL/gl.h:1273
GL_GENERATE_MIPMAP_HINT = 33170 	# /usr/include/GL/gl.h:1274
GL_BLEND_DST_RGB = 32968 	# /usr/include/GL/gl.h:1275
GL_BLEND_SRC_RGB = 32969 	# /usr/include/GL/gl.h:1276
GL_BLEND_DST_ALPHA = 32970 	# /usr/include/GL/gl.h:1277
GL_BLEND_SRC_ALPHA = 32971 	# /usr/include/GL/gl.h:1278
GL_MIRRORED_REPEAT = 33648 	# /usr/include/GL/gl.h:1279
GL_DEPTH_COMPONENT16 = 33189 	# /usr/include/GL/gl.h:1280
GL_DEPTH_COMPONENT24 = 33190 	# /usr/include/GL/gl.h:1281
GL_DEPTH_COMPONENT32 = 33191 	# /usr/include/GL/gl.h:1282
GL_TEXTURE_DEPTH_SIZE = 34890 	# /usr/include/GL/gl.h:1283
GL_DEPTH_TEXTURE_MODE = 34891 	# /usr/include/GL/gl.h:1284
GL_TEXTURE_COMPARE_MODE = 34892 	# /usr/include/GL/gl.h:1285
GL_TEXTURE_COMPARE_FUNC = 34893 	# /usr/include/GL/gl.h:1286
GL_COMPARE_R_TO_TEXTURE = 34894 	# /usr/include/GL/gl.h:1287
# /usr/include/GL/gl.h:1291
glAccum = _link_function('glAccum', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1292
glAlphaFunc = _link_function('glAlphaFunc', None, [GLenum, GLclampf], None)

# /usr/include/GL/gl.h:1293
glAreTexturesResident = _link_function('glAreTexturesResident', GLboolean, [GLsizei, POINTER(GLuint), POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:1294
glArrayElement = _link_function('glArrayElement', None, [GLint], None)

# /usr/include/GL/gl.h:1295
glBegin = _link_function('glBegin', None, [GLenum], None)

# /usr/include/GL/gl.h:1296
glBindTexture = _link_function('glBindTexture', None, [GLenum, GLuint], None)

# /usr/include/GL/gl.h:1297
glBitmap = _link_function('glBitmap', None, [GLsizei, GLsizei, GLfloat, GLfloat, GLfloat, GLfloat, POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1298
glBlendFunc = _link_function('glBlendFunc', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:1299
glCallList = _link_function('glCallList', None, [GLuint], None)

# /usr/include/GL/gl.h:1300
glCallLists = _link_function('glCallLists', None, [GLsizei, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1301
glClear = _link_function('glClear', None, [GLbitfield], None)

# /usr/include/GL/gl.h:1302
glClearAccum = _link_function('glClearAccum', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1303
glClearColor = _link_function('glClearColor', None, [GLclampf, GLclampf, GLclampf, GLclampf], None)

# /usr/include/GL/gl.h:1304
glClearDepth = _link_function('glClearDepth', None, [GLclampd], None)

# /usr/include/GL/gl.h:1305
glClearIndex = _link_function('glClearIndex', None, [GLfloat], None)

# /usr/include/GL/gl.h:1306
glClearStencil = _link_function('glClearStencil', None, [GLint], None)

# /usr/include/GL/gl.h:1307
glClipPlane = _link_function('glClipPlane', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1308
glColor3b = _link_function('glColor3b', None, [GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:1309
glColor3bv = _link_function('glColor3bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:1310
glColor3d = _link_function('glColor3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1311
glColor3dv = _link_function('glColor3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1312
glColor3f = _link_function('glColor3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1313
glColor3fv = _link_function('glColor3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1314
glColor3i = _link_function('glColor3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1315
glColor3iv = _link_function('glColor3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1316
glColor3s = _link_function('glColor3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1317
glColor3sv = _link_function('glColor3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1318
glColor3ub = _link_function('glColor3ub', None, [GLubyte, GLubyte, GLubyte], None)

# /usr/include/GL/gl.h:1319
glColor3ubv = _link_function('glColor3ubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1320
glColor3ui = _link_function('glColor3ui', None, [GLuint, GLuint, GLuint], None)

# /usr/include/GL/gl.h:1321
glColor3uiv = _link_function('glColor3uiv', None, [POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1322
glColor3us = _link_function('glColor3us', None, [GLushort, GLushort, GLushort], None)

# /usr/include/GL/gl.h:1323
glColor3usv = _link_function('glColor3usv', None, [POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1324
glColor4b = _link_function('glColor4b', None, [GLbyte, GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:1325
glColor4bv = _link_function('glColor4bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:1326
glColor4d = _link_function('glColor4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1327
glColor4dv = _link_function('glColor4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1328
glColor4f = _link_function('glColor4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1329
glColor4fv = _link_function('glColor4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1330
glColor4i = _link_function('glColor4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1331
glColor4iv = _link_function('glColor4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1332
glColor4s = _link_function('glColor4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1333
glColor4sv = _link_function('glColor4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1334
glColor4ub = _link_function('glColor4ub', None, [GLubyte, GLubyte, GLubyte, GLubyte], None)

# /usr/include/GL/gl.h:1335
glColor4ubv = _link_function('glColor4ubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1336
glColor4ui = _link_function('glColor4ui', None, [GLuint, GLuint, GLuint, GLuint], None)

# /usr/include/GL/gl.h:1337
glColor4uiv = _link_function('glColor4uiv', None, [POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1338
glColor4us = _link_function('glColor4us', None, [GLushort, GLushort, GLushort, GLushort], None)

# /usr/include/GL/gl.h:1339
glColor4usv = _link_function('glColor4usv', None, [POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1340
glColorMask = _link_function('glColorMask', None, [GLboolean, GLboolean, GLboolean, GLboolean], None)

# /usr/include/GL/gl.h:1341
glColorMaterial = _link_function('glColorMaterial', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:1342
glColorPointer = _link_function('glColorPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1343
glCopyPixels = _link_function('glCopyPixels', None, [GLint, GLint, GLsizei, GLsizei, GLenum], None)

# /usr/include/GL/gl.h:1344
glCopyTexImage1D = _link_function('glCopyTexImage1D', None, [GLenum, GLint, GLenum, GLint, GLint, GLsizei, GLint], None)

# /usr/include/GL/gl.h:1345
glCopyTexImage2D = _link_function('glCopyTexImage2D', None, [GLenum, GLint, GLenum, GLint, GLint, GLsizei, GLsizei, GLint], None)

# /usr/include/GL/gl.h:1346
glCopyTexSubImage1D = _link_function('glCopyTexSubImage1D', None, [GLenum, GLint, GLint, GLint, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1347
glCopyTexSubImage2D = _link_function('glCopyTexSubImage2D', None, [GLenum, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:1348
glCullFace = _link_function('glCullFace', None, [GLenum], None)

# /usr/include/GL/gl.h:1349
glDeleteLists = _link_function('glDeleteLists', None, [GLuint, GLsizei], None)

# /usr/include/GL/gl.h:1350
glDeleteTextures = _link_function('glDeleteTextures', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1351
glDepthFunc = _link_function('glDepthFunc', None, [GLenum], None)

# /usr/include/GL/gl.h:1352
glDepthMask = _link_function('glDepthMask', None, [GLboolean], None)

# /usr/include/GL/gl.h:1353
glDepthRange = _link_function('glDepthRange', None, [GLclampd, GLclampd], None)

# /usr/include/GL/gl.h:1354
glDisable = _link_function('glDisable', None, [GLenum], None)

# /usr/include/GL/gl.h:1355
glDisableClientState = _link_function('glDisableClientState', None, [GLenum], None)

# /usr/include/GL/gl.h:1356
glDrawArrays = _link_function('glDrawArrays', None, [GLenum, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1357
glDrawBuffer = _link_function('glDrawBuffer', None, [GLenum], None)

# /usr/include/GL/gl.h:1358
glDrawElements = _link_function('glDrawElements', None, [GLenum, GLsizei, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1359
glDrawPixels = _link_function('glDrawPixels', None, [GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1360
glEdgeFlag = _link_function('glEdgeFlag', None, [GLboolean], None)

# /usr/include/GL/gl.h:1361
glEdgeFlagPointer = _link_function('glEdgeFlagPointer', None, [GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1362
glEdgeFlagv = _link_function('glEdgeFlagv', None, [POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:1363
glEnable = _link_function('glEnable', None, [GLenum], None)

# /usr/include/GL/gl.h:1364
glEnableClientState = _link_function('glEnableClientState', None, [GLenum], None)

# /usr/include/GL/gl.h:1365
glEnd = _link_function('glEnd', None, [], None)

# /usr/include/GL/gl.h:1366
glEndList = _link_function('glEndList', None, [], None)

# /usr/include/GL/gl.h:1367
glEvalCoord1d = _link_function('glEvalCoord1d', None, [GLdouble], None)

# /usr/include/GL/gl.h:1368
glEvalCoord1dv = _link_function('glEvalCoord1dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1369
glEvalCoord1f = _link_function('glEvalCoord1f', None, [GLfloat], None)

# /usr/include/GL/gl.h:1370
glEvalCoord1fv = _link_function('glEvalCoord1fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1371
glEvalCoord2d = _link_function('glEvalCoord2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1372
glEvalCoord2dv = _link_function('glEvalCoord2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1373
glEvalCoord2f = _link_function('glEvalCoord2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1374
glEvalCoord2fv = _link_function('glEvalCoord2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1375
glEvalMesh1 = _link_function('glEvalMesh1', None, [GLenum, GLint, GLint], None)

# /usr/include/GL/gl.h:1376
glEvalMesh2 = _link_function('glEvalMesh2', None, [GLenum, GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1377
glEvalPoint1 = _link_function('glEvalPoint1', None, [GLint], None)

# /usr/include/GL/gl.h:1378
glEvalPoint2 = _link_function('glEvalPoint2', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1379
glFeedbackBuffer = _link_function('glFeedbackBuffer', None, [GLsizei, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1380
glFinish = _link_function('glFinish', None, [], None)

# /usr/include/GL/gl.h:1381
glFlush = _link_function('glFlush', None, [], None)

# /usr/include/GL/gl.h:1382
glFogf = _link_function('glFogf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1383
glFogfv = _link_function('glFogfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1384
glFogi = _link_function('glFogi', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1385
glFogiv = _link_function('glFogiv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1386
glFrontFace = _link_function('glFrontFace', None, [GLenum], None)

# /usr/include/GL/gl.h:1387
glFrustum = _link_function('glFrustum', None, [GLdouble, GLdouble, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1388
glGenLists = _link_function('glGenLists', GLuint, [GLsizei], None)

# /usr/include/GL/gl.h:1389
glGenTextures = _link_function('glGenTextures', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1390
glGetBooleanv = _link_function('glGetBooleanv', None, [GLenum, POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:1391
glGetClipPlane = _link_function('glGetClipPlane', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1392
glGetDoublev = _link_function('glGetDoublev', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1393
glGetError = _link_function('glGetError', GLenum, [], None)

# /usr/include/GL/gl.h:1394
glGetFloatv = _link_function('glGetFloatv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1395
glGetIntegerv = _link_function('glGetIntegerv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1396
glGetLightfv = _link_function('glGetLightfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1397
glGetLightiv = _link_function('glGetLightiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1398
glGetMapdv = _link_function('glGetMapdv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1399
glGetMapfv = _link_function('glGetMapfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1400
glGetMapiv = _link_function('glGetMapiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1401
glGetMaterialfv = _link_function('glGetMaterialfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1402
glGetMaterialiv = _link_function('glGetMaterialiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1403
glGetPixelMapfv = _link_function('glGetPixelMapfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1404
glGetPixelMapuiv = _link_function('glGetPixelMapuiv', None, [GLenum, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1405
glGetPixelMapusv = _link_function('glGetPixelMapusv', None, [GLenum, POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1406
glGetPointerv = _link_function('glGetPointerv', None, [GLenum, POINTER(POINTER(GLvoid))], None)

# /usr/include/GL/gl.h:1407
glGetPolygonStipple = _link_function('glGetPolygonStipple', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1408
glGetString = _link_function('glGetString', POINTER(GLubyte), [GLenum], None)

# /usr/include/GL/gl.h:1409
glGetTexEnvfv = _link_function('glGetTexEnvfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1410
glGetTexEnviv = _link_function('glGetTexEnviv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1411
glGetTexGendv = _link_function('glGetTexGendv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1412
glGetTexGenfv = _link_function('glGetTexGenfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1413
glGetTexGeniv = _link_function('glGetTexGeniv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1414
glGetTexImage = _link_function('glGetTexImage', None, [GLenum, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1415
glGetTexLevelParameterfv = _link_function('glGetTexLevelParameterfv', None, [GLenum, GLint, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1416
glGetTexLevelParameteriv = _link_function('glGetTexLevelParameteriv', None, [GLenum, GLint, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1417
glGetTexParameterfv = _link_function('glGetTexParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1418
glGetTexParameteriv = _link_function('glGetTexParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1419
glHint = _link_function('glHint', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:1420
glIndexMask = _link_function('glIndexMask', None, [GLuint], None)

# /usr/include/GL/gl.h:1421
glIndexPointer = _link_function('glIndexPointer', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1422
glIndexd = _link_function('glIndexd', None, [GLdouble], None)

# /usr/include/GL/gl.h:1423
glIndexdv = _link_function('glIndexdv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1424
glIndexf = _link_function('glIndexf', None, [GLfloat], None)

# /usr/include/GL/gl.h:1425
glIndexfv = _link_function('glIndexfv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1426
glIndexi = _link_function('glIndexi', None, [GLint], None)

# /usr/include/GL/gl.h:1427
glIndexiv = _link_function('glIndexiv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1428
glIndexs = _link_function('glIndexs', None, [GLshort], None)

# /usr/include/GL/gl.h:1429
glIndexsv = _link_function('glIndexsv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1430
glIndexub = _link_function('glIndexub', None, [GLubyte], None)

# /usr/include/GL/gl.h:1431
glIndexubv = _link_function('glIndexubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1432
glInitNames = _link_function('glInitNames', None, [], None)

# /usr/include/GL/gl.h:1433
glInterleavedArrays = _link_function('glInterleavedArrays', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1434
glIsEnabled = _link_function('glIsEnabled', GLboolean, [GLenum], None)

# /usr/include/GL/gl.h:1435
glIsList = _link_function('glIsList', GLboolean, [GLuint], None)

# /usr/include/GL/gl.h:1436
glIsTexture = _link_function('glIsTexture', GLboolean, [GLuint], None)

# /usr/include/GL/gl.h:1437
glLightModelf = _link_function('glLightModelf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1438
glLightModelfv = _link_function('glLightModelfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1439
glLightModeli = _link_function('glLightModeli', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1440
glLightModeliv = _link_function('glLightModeliv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1441
glLightf = _link_function('glLightf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1442
glLightfv = _link_function('glLightfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1443
glLighti = _link_function('glLighti', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1444
glLightiv = _link_function('glLightiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1445
glLineStipple = _link_function('glLineStipple', None, [GLint, GLushort], None)

# /usr/include/GL/gl.h:1446
glLineWidth = _link_function('glLineWidth', None, [GLfloat], None)

# /usr/include/GL/gl.h:1447
glListBase = _link_function('glListBase', None, [GLuint], None)

# /usr/include/GL/gl.h:1448
glLoadIdentity = _link_function('glLoadIdentity', None, [], None)

# /usr/include/GL/gl.h:1449
glLoadMatrixd = _link_function('glLoadMatrixd', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1450
glLoadMatrixf = _link_function('glLoadMatrixf', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1451
glLoadName = _link_function('glLoadName', None, [GLuint], None)

# /usr/include/GL/gl.h:1452
glLogicOp = _link_function('glLogicOp', None, [GLenum], None)

# /usr/include/GL/gl.h:1453
glMap1d = _link_function('glMap1d', None, [GLenum, GLdouble, GLdouble, GLint, GLint, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1454
glMap1f = _link_function('glMap1f', None, [GLenum, GLfloat, GLfloat, GLint, GLint, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1455
glMap2d = _link_function('glMap2d', None, [GLenum, GLdouble, GLdouble, GLint, GLint, GLdouble, GLdouble, GLint, GLint, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1456
glMap2f = _link_function('glMap2f', None, [GLenum, GLfloat, GLfloat, GLint, GLint, GLfloat, GLfloat, GLint, GLint, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1457
glMapGrid1d = _link_function('glMapGrid1d', None, [GLint, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1458
glMapGrid1f = _link_function('glMapGrid1f', None, [GLint, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1459
glMapGrid2d = _link_function('glMapGrid2d', None, [GLint, GLdouble, GLdouble, GLint, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1460
glMapGrid2f = _link_function('glMapGrid2f', None, [GLint, GLfloat, GLfloat, GLint, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1461
glMaterialf = _link_function('glMaterialf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1462
glMaterialfv = _link_function('glMaterialfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1463
glMateriali = _link_function('glMateriali', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1464
glMaterialiv = _link_function('glMaterialiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1465
glMatrixMode = _link_function('glMatrixMode', None, [GLenum], None)

# /usr/include/GL/gl.h:1466
glMultMatrixd = _link_function('glMultMatrixd', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1467
glMultMatrixf = _link_function('glMultMatrixf', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1468
glNewList = _link_function('glNewList', None, [GLuint, GLenum], None)

# /usr/include/GL/gl.h:1469
glNormal3b = _link_function('glNormal3b', None, [GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:1470
glNormal3bv = _link_function('glNormal3bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:1471
glNormal3d = _link_function('glNormal3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1472
glNormal3dv = _link_function('glNormal3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1473
glNormal3f = _link_function('glNormal3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1474
glNormal3fv = _link_function('glNormal3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1475
glNormal3i = _link_function('glNormal3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1476
glNormal3iv = _link_function('glNormal3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1477
glNormal3s = _link_function('glNormal3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1478
glNormal3sv = _link_function('glNormal3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1479
glNormalPointer = _link_function('glNormalPointer', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1480
glOrtho = _link_function('glOrtho', None, [GLdouble, GLdouble, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1481
glPassThrough = _link_function('glPassThrough', None, [GLfloat], None)

# /usr/include/GL/gl.h:1482
glPixelMapfv = _link_function('glPixelMapfv', None, [GLenum, GLsizei, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1483
glPixelMapuiv = _link_function('glPixelMapuiv', None, [GLenum, GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1484
glPixelMapusv = _link_function('glPixelMapusv', None, [GLenum, GLsizei, POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1485
glPixelStoref = _link_function('glPixelStoref', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1486
glPixelStorei = _link_function('glPixelStorei', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1487
glPixelTransferf = _link_function('glPixelTransferf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1488
glPixelTransferi = _link_function('glPixelTransferi', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1489
glPixelZoom = _link_function('glPixelZoom', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1490
glPointSize = _link_function('glPointSize', None, [GLfloat], None)

# /usr/include/GL/gl.h:1491
glPolygonMode = _link_function('glPolygonMode', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:1492
glPolygonOffset = _link_function('glPolygonOffset', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1493
glPolygonStipple = _link_function('glPolygonStipple', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1494
glPopAttrib = _link_function('glPopAttrib', None, [], None)

# /usr/include/GL/gl.h:1495
glPopClientAttrib = _link_function('glPopClientAttrib', None, [], None)

# /usr/include/GL/gl.h:1496
glPopMatrix = _link_function('glPopMatrix', None, [], None)

# /usr/include/GL/gl.h:1497
glPopName = _link_function('glPopName', None, [], None)

# /usr/include/GL/gl.h:1498
glPrioritizeTextures = _link_function('glPrioritizeTextures', None, [GLsizei, POINTER(GLuint), POINTER(GLclampf)], None)

# /usr/include/GL/gl.h:1499
glPushAttrib = _link_function('glPushAttrib', None, [GLbitfield], None)

# /usr/include/GL/gl.h:1500
glPushClientAttrib = _link_function('glPushClientAttrib', None, [GLbitfield], None)

# /usr/include/GL/gl.h:1501
glPushMatrix = _link_function('glPushMatrix', None, [], None)

# /usr/include/GL/gl.h:1502
glPushName = _link_function('glPushName', None, [GLuint], None)

# /usr/include/GL/gl.h:1503
glRasterPos2d = _link_function('glRasterPos2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1504
glRasterPos2dv = _link_function('glRasterPos2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1505
glRasterPos2f = _link_function('glRasterPos2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1506
glRasterPos2fv = _link_function('glRasterPos2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1507
glRasterPos2i = _link_function('glRasterPos2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1508
glRasterPos2iv = _link_function('glRasterPos2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1509
glRasterPos2s = _link_function('glRasterPos2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:1510
glRasterPos2sv = _link_function('glRasterPos2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1511
glRasterPos3d = _link_function('glRasterPos3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1512
glRasterPos3dv = _link_function('glRasterPos3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1513
glRasterPos3f = _link_function('glRasterPos3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1514
glRasterPos3fv = _link_function('glRasterPos3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1515
glRasterPos3i = _link_function('glRasterPos3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1516
glRasterPos3iv = _link_function('glRasterPos3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1517
glRasterPos3s = _link_function('glRasterPos3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1518
glRasterPos3sv = _link_function('glRasterPos3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1519
glRasterPos4d = _link_function('glRasterPos4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1520
glRasterPos4dv = _link_function('glRasterPos4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1521
glRasterPos4f = _link_function('glRasterPos4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1522
glRasterPos4fv = _link_function('glRasterPos4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1523
glRasterPos4i = _link_function('glRasterPos4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1524
glRasterPos4iv = _link_function('glRasterPos4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1525
glRasterPos4s = _link_function('glRasterPos4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1526
glRasterPos4sv = _link_function('glRasterPos4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1527
glReadBuffer = _link_function('glReadBuffer', None, [GLenum], None)

# /usr/include/GL/gl.h:1528
glReadPixels = _link_function('glReadPixels', None, [GLint, GLint, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1529
glRectd = _link_function('glRectd', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1530
glRectdv = _link_function('glRectdv', None, [POINTER(GLdouble), POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1531
glRectf = _link_function('glRectf', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1532
glRectfv = _link_function('glRectfv', None, [POINTER(GLfloat), POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1533
glRecti = _link_function('glRecti', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1534
glRectiv = _link_function('glRectiv', None, [POINTER(GLint), POINTER(GLint)], None)

# /usr/include/GL/gl.h:1535
glRects = _link_function('glRects', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1536
glRectsv = _link_function('glRectsv', None, [POINTER(GLshort), POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1537
glRenderMode = _link_function('glRenderMode', GLint, [GLenum], None)

# /usr/include/GL/gl.h:1538
glRotated = _link_function('glRotated', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1539
glRotatef = _link_function('glRotatef', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1540
glScaled = _link_function('glScaled', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1541
glScalef = _link_function('glScalef', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1542
glScissor = _link_function('glScissor', None, [GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:1543
glSelectBuffer = _link_function('glSelectBuffer', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1544
glShadeModel = _link_function('glShadeModel', None, [GLenum], None)

# /usr/include/GL/gl.h:1545
glStencilFunc = _link_function('glStencilFunc', None, [GLenum, GLint, GLuint], None)

# /usr/include/GL/gl.h:1546
glStencilMask = _link_function('glStencilMask', None, [GLuint], None)

# /usr/include/GL/gl.h:1547
glStencilOp = _link_function('glStencilOp', None, [GLenum, GLenum, GLenum], None)

# /usr/include/GL/gl.h:1548
glTexCoord1d = _link_function('glTexCoord1d', None, [GLdouble], None)

# /usr/include/GL/gl.h:1549
glTexCoord1dv = _link_function('glTexCoord1dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1550
glTexCoord1f = _link_function('glTexCoord1f', None, [GLfloat], None)

# /usr/include/GL/gl.h:1551
glTexCoord1fv = _link_function('glTexCoord1fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1552
glTexCoord1i = _link_function('glTexCoord1i', None, [GLint], None)

# /usr/include/GL/gl.h:1553
glTexCoord1iv = _link_function('glTexCoord1iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1554
glTexCoord1s = _link_function('glTexCoord1s', None, [GLshort], None)

# /usr/include/GL/gl.h:1555
glTexCoord1sv = _link_function('glTexCoord1sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1556
glTexCoord2d = _link_function('glTexCoord2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1557
glTexCoord2dv = _link_function('glTexCoord2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1558
glTexCoord2f = _link_function('glTexCoord2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1559
glTexCoord2fv = _link_function('glTexCoord2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1560
glTexCoord2i = _link_function('glTexCoord2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1561
glTexCoord2iv = _link_function('glTexCoord2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1562
glTexCoord2s = _link_function('glTexCoord2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:1563
glTexCoord2sv = _link_function('glTexCoord2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1564
glTexCoord3d = _link_function('glTexCoord3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1565
glTexCoord3dv = _link_function('glTexCoord3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1566
glTexCoord3f = _link_function('glTexCoord3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1567
glTexCoord3fv = _link_function('glTexCoord3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1568
glTexCoord3i = _link_function('glTexCoord3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1569
glTexCoord3iv = _link_function('glTexCoord3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1570
glTexCoord3s = _link_function('glTexCoord3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1571
glTexCoord3sv = _link_function('glTexCoord3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1572
glTexCoord4d = _link_function('glTexCoord4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1573
glTexCoord4dv = _link_function('glTexCoord4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1574
glTexCoord4f = _link_function('glTexCoord4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1575
glTexCoord4fv = _link_function('glTexCoord4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1576
glTexCoord4i = _link_function('glTexCoord4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1577
glTexCoord4iv = _link_function('glTexCoord4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1578
glTexCoord4s = _link_function('glTexCoord4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1579
glTexCoord4sv = _link_function('glTexCoord4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1580
glTexCoordPointer = _link_function('glTexCoordPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1581
glTexEnvf = _link_function('glTexEnvf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1582
glTexEnvfv = _link_function('glTexEnvfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1583
glTexEnvi = _link_function('glTexEnvi', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1584
glTexEnviv = _link_function('glTexEnviv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1585
glTexGend = _link_function('glTexGend', None, [GLenum, GLenum, GLdouble], None)

# /usr/include/GL/gl.h:1586
glTexGendv = _link_function('glTexGendv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1587
glTexGenf = _link_function('glTexGenf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1588
glTexGenfv = _link_function('glTexGenfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1589
glTexGeni = _link_function('glTexGeni', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1590
glTexGeniv = _link_function('glTexGeniv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1591
glTexImage1D = _link_function('glTexImage1D', None, [GLenum, GLint, GLint, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1592
glTexImage2D = _link_function('glTexImage2D', None, [GLenum, GLint, GLint, GLsizei, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1593
glTexParameterf = _link_function('glTexParameterf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1594
glTexParameterfv = _link_function('glTexParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1595
glTexParameteri = _link_function('glTexParameteri', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1596
glTexParameteriv = _link_function('glTexParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1597
glTexSubImage1D = _link_function('glTexSubImage1D', None, [GLenum, GLint, GLint, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1598
glTexSubImage2D = _link_function('glTexSubImage2D', None, [GLenum, GLint, GLint, GLint, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1599
glTranslated = _link_function('glTranslated', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1600
glTranslatef = _link_function('glTranslatef', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1601
glVertex2d = _link_function('glVertex2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1602
glVertex2dv = _link_function('glVertex2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1603
glVertex2f = _link_function('glVertex2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1604
glVertex2fv = _link_function('glVertex2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1605
glVertex2i = _link_function('glVertex2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1606
glVertex2iv = _link_function('glVertex2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1607
glVertex2s = _link_function('glVertex2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:1608
glVertex2sv = _link_function('glVertex2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1609
glVertex3d = _link_function('glVertex3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1610
glVertex3dv = _link_function('glVertex3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1611
glVertex3f = _link_function('glVertex3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1612
glVertex3fv = _link_function('glVertex3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1613
glVertex3i = _link_function('glVertex3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1614
glVertex3iv = _link_function('glVertex3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1615
glVertex3s = _link_function('glVertex3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1616
glVertex3sv = _link_function('glVertex3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1617
glVertex4d = _link_function('glVertex4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1618
glVertex4dv = _link_function('glVertex4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1619
glVertex4f = _link_function('glVertex4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1620
glVertex4fv = _link_function('glVertex4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1621
glVertex4i = _link_function('glVertex4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1622
glVertex4iv = _link_function('glVertex4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1623
glVertex4s = _link_function('glVertex4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1624
glVertex4sv = _link_function('glVertex4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1625
glVertexPointer = _link_function('glVertexPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1626
glViewport = _link_function('glViewport', None, [GLint, GLint, GLsizei, GLsizei], None)


__all__ = ['GLenum', 'GLboolean', 'GLbitfield', 'GLbyte', 'GLshort', 'GLint',
'GLsizei', 'GLubyte', 'GLushort', 'GLuint', 'GLfloat', 'GLclampf', 'GLdouble',
'GLclampd', 'GLvoid', 'GL_VERSION_1_1', 'GL_CURRENT_BIT', 'GL_POINT_BIT',
'GL_LINE_BIT', 'GL_POLYGON_BIT', 'GL_POLYGON_STIPPLE_BIT',
'GL_PIXEL_MODE_BIT', 'GL_LIGHTING_BIT', 'GL_FOG_BIT', 'GL_DEPTH_BUFFER_BIT',
'GL_ACCUM_BUFFER_BIT', 'GL_STENCIL_BUFFER_BIT', 'GL_VIEWPORT_BIT',
'GL_TRANSFORM_BIT', 'GL_ENABLE_BIT', 'GL_COLOR_BUFFER_BIT', 'GL_HINT_BIT',
'GL_EVAL_BIT', 'GL_LIST_BIT', 'GL_TEXTURE_BIT', 'GL_SCISSOR_BIT',
'GL_ALL_ATTRIB_BITS', 'GL_CLIENT_PIXEL_STORE_BIT',
'GL_CLIENT_VERTEX_ARRAY_BIT', 'GL_CLIENT_ALL_ATTRIB_BITS', 'GL_FALSE',
'GL_TRUE', 'GL_POINTS', 'GL_LINES', 'GL_LINE_LOOP', 'GL_LINE_STRIP',
'GL_TRIANGLES', 'GL_TRIANGLE_STRIP', 'GL_TRIANGLE_FAN', 'GL_QUADS',
'GL_QUAD_STRIP', 'GL_POLYGON', 'GL_ACCUM', 'GL_LOAD', 'GL_RETURN', 'GL_MULT',
'GL_ADD', 'GL_NEVER', 'GL_LESS', 'GL_EQUAL', 'GL_LEQUAL', 'GL_GREATER',
'GL_NOTEQUAL', 'GL_GEQUAL', 'GL_ALWAYS', 'GL_ZERO', 'GL_ONE', 'GL_SRC_COLOR',
'GL_ONE_MINUS_SRC_COLOR', 'GL_SRC_ALPHA', 'GL_ONE_MINUS_SRC_ALPHA',
'GL_DST_ALPHA', 'GL_ONE_MINUS_DST_ALPHA', 'GL_DST_COLOR',
'GL_ONE_MINUS_DST_COLOR', 'GL_SRC_ALPHA_SATURATE', 'GL_NONE', 'GL_FRONT_LEFT',
'GL_FRONT_RIGHT', 'GL_BACK_LEFT', 'GL_BACK_RIGHT', 'GL_FRONT', 'GL_BACK',
'GL_LEFT', 'GL_RIGHT', 'GL_FRONT_AND_BACK', 'GL_AUX0', 'GL_AUX1', 'GL_AUX2',
'GL_AUX3', 'GL_NO_ERROR', 'GL_INVALID_ENUM', 'GL_INVALID_VALUE',
'GL_INVALID_OPERATION', 'GL_STACK_OVERFLOW', 'GL_STACK_UNDERFLOW',
'GL_OUT_OF_MEMORY', 'GL_TABLE_TOO_LARGE', 'GL_2D', 'GL_3D', 'GL_3D_COLOR',
'GL_3D_COLOR_TEXTURE', 'GL_4D_COLOR_TEXTURE', 'GL_PASS_THROUGH_TOKEN',
'GL_POINT_TOKEN', 'GL_LINE_TOKEN', 'GL_POLYGON_TOKEN', 'GL_BITMAP_TOKEN',
'GL_DRAW_PIXEL_TOKEN', 'GL_COPY_PIXEL_TOKEN', 'GL_LINE_RESET_TOKEN', 'GL_EXP',
'GL_EXP2', 'GL_CW', 'GL_CCW', 'GL_COEFF', 'GL_ORDER', 'GL_DOMAIN',
'GL_PIXEL_MAP_I_TO_I', 'GL_PIXEL_MAP_S_TO_S', 'GL_PIXEL_MAP_I_TO_R',
'GL_PIXEL_MAP_I_TO_G', 'GL_PIXEL_MAP_I_TO_B', 'GL_PIXEL_MAP_I_TO_A',
'GL_PIXEL_MAP_R_TO_R', 'GL_PIXEL_MAP_G_TO_G', 'GL_PIXEL_MAP_B_TO_B',
'GL_PIXEL_MAP_A_TO_A', 'GL_VERTEX_ARRAY_POINTER', 'GL_NORMAL_ARRAY_POINTER',
'GL_COLOR_ARRAY_POINTER', 'GL_INDEX_ARRAY_POINTER',
'GL_TEXTURE_COORD_ARRAY_POINTER', 'GL_EDGE_FLAG_ARRAY_POINTER',
'GL_CURRENT_COLOR', 'GL_CURRENT_INDEX', 'GL_CURRENT_NORMAL',
'GL_CURRENT_TEXTURE_COORDS', 'GL_CURRENT_RASTER_COLOR',
'GL_CURRENT_RASTER_INDEX', 'GL_CURRENT_RASTER_TEXTURE_COORDS',
'GL_CURRENT_RASTER_POSITION', 'GL_CURRENT_RASTER_POSITION_VALID',
'GL_CURRENT_RASTER_DISTANCE', 'GL_POINT_SMOOTH', 'GL_POINT_SIZE',
'GL_SMOOTH_POINT_SIZE_RANGE', 'GL_SMOOTH_POINT_SIZE_GRANULARITY',
'GL_POINT_SIZE_RANGE', 'GL_POINT_SIZE_GRANULARITY', 'GL_LINE_SMOOTH',
'GL_LINE_WIDTH', 'GL_SMOOTH_LINE_WIDTH_RANGE',
'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 'GL_LINE_WIDTH_RANGE',
'GL_LINE_WIDTH_GRANULARITY', 'GL_LINE_STIPPLE', 'GL_LINE_STIPPLE_PATTERN',
'GL_LINE_STIPPLE_REPEAT', 'GL_LIST_MODE', 'GL_MAX_LIST_NESTING',
'GL_LIST_BASE', 'GL_LIST_INDEX', 'GL_POLYGON_MODE', 'GL_POLYGON_SMOOTH',
'GL_POLYGON_STIPPLE', 'GL_EDGE_FLAG', 'GL_CULL_FACE', 'GL_CULL_FACE_MODE',
'GL_FRONT_FACE', 'GL_LIGHTING', 'GL_LIGHT_MODEL_LOCAL_VIEWER',
'GL_LIGHT_MODEL_TWO_SIDE', 'GL_LIGHT_MODEL_AMBIENT', 'GL_SHADE_MODEL',
'GL_COLOR_MATERIAL_FACE', 'GL_COLOR_MATERIAL_PARAMETER', 'GL_COLOR_MATERIAL',
'GL_FOG', 'GL_FOG_INDEX', 'GL_FOG_DENSITY', 'GL_FOG_START', 'GL_FOG_END',
'GL_FOG_MODE', 'GL_FOG_COLOR', 'GL_DEPTH_RANGE', 'GL_DEPTH_TEST',
'GL_DEPTH_WRITEMASK', 'GL_DEPTH_CLEAR_VALUE', 'GL_DEPTH_FUNC',
'GL_ACCUM_CLEAR_VALUE', 'GL_STENCIL_TEST', 'GL_STENCIL_CLEAR_VALUE',
'GL_STENCIL_FUNC', 'GL_STENCIL_VALUE_MASK', 'GL_STENCIL_FAIL',
'GL_STENCIL_PASS_DEPTH_FAIL', 'GL_STENCIL_PASS_DEPTH_PASS', 'GL_STENCIL_REF',
'GL_STENCIL_WRITEMASK', 'GL_MATRIX_MODE', 'GL_NORMALIZE', 'GL_VIEWPORT',
'GL_MODELVIEW_STACK_DEPTH', 'GL_PROJECTION_STACK_DEPTH',
'GL_TEXTURE_STACK_DEPTH', 'GL_MODELVIEW_MATRIX', 'GL_PROJECTION_MATRIX',
'GL_TEXTURE_MATRIX', 'GL_ATTRIB_STACK_DEPTH', 'GL_CLIENT_ATTRIB_STACK_DEPTH',
'GL_ALPHA_TEST', 'GL_ALPHA_TEST_FUNC', 'GL_ALPHA_TEST_REF', 'GL_DITHER',
'GL_BLEND_DST', 'GL_BLEND_SRC', 'GL_BLEND', 'GL_LOGIC_OP_MODE',
'GL_INDEX_LOGIC_OP', 'GL_LOGIC_OP', 'GL_COLOR_LOGIC_OP', 'GL_AUX_BUFFERS',
'GL_DRAW_BUFFER', 'GL_READ_BUFFER', 'GL_SCISSOR_BOX', 'GL_SCISSOR_TEST',
'GL_INDEX_CLEAR_VALUE', 'GL_INDEX_WRITEMASK', 'GL_COLOR_CLEAR_VALUE',
'GL_COLOR_WRITEMASK', 'GL_INDEX_MODE', 'GL_RGBA_MODE', 'GL_DOUBLEBUFFER',
'GL_STEREO', 'GL_RENDER_MODE', 'GL_PERSPECTIVE_CORRECTION_HINT',
'GL_POINT_SMOOTH_HINT', 'GL_LINE_SMOOTH_HINT', 'GL_POLYGON_SMOOTH_HINT',
'GL_FOG_HINT', 'GL_TEXTURE_GEN_S', 'GL_TEXTURE_GEN_T', 'GL_TEXTURE_GEN_R',
'GL_TEXTURE_GEN_Q', 'GL_PIXEL_MAP_I_TO_I_SIZE', 'GL_PIXEL_MAP_S_TO_S_SIZE',
'GL_PIXEL_MAP_I_TO_R_SIZE', 'GL_PIXEL_MAP_I_TO_G_SIZE',
'GL_PIXEL_MAP_I_TO_B_SIZE', 'GL_PIXEL_MAP_I_TO_A_SIZE',
'GL_PIXEL_MAP_R_TO_R_SIZE', 'GL_PIXEL_MAP_G_TO_G_SIZE',
'GL_PIXEL_MAP_B_TO_B_SIZE', 'GL_PIXEL_MAP_A_TO_A_SIZE',
'GL_UNPACK_SWAP_BYTES', 'GL_UNPACK_LSB_FIRST', 'GL_UNPACK_ROW_LENGTH',
'GL_UNPACK_SKIP_ROWS', 'GL_UNPACK_SKIP_PIXELS', 'GL_UNPACK_ALIGNMENT',
'GL_PACK_SWAP_BYTES', 'GL_PACK_LSB_FIRST', 'GL_PACK_ROW_LENGTH',
'GL_PACK_SKIP_ROWS', 'GL_PACK_SKIP_PIXELS', 'GL_PACK_ALIGNMENT',
'GL_MAP_COLOR', 'GL_MAP_STENCIL', 'GL_INDEX_SHIFT', 'GL_INDEX_OFFSET',
'GL_RED_SCALE', 'GL_RED_BIAS', 'GL_ZOOM_X', 'GL_ZOOM_Y', 'GL_GREEN_SCALE',
'GL_GREEN_BIAS', 'GL_BLUE_SCALE', 'GL_BLUE_BIAS', 'GL_ALPHA_SCALE',
'GL_ALPHA_BIAS', 'GL_DEPTH_SCALE', 'GL_DEPTH_BIAS', 'GL_MAX_EVAL_ORDER',
'GL_MAX_LIGHTS', 'GL_MAX_CLIP_PLANES', 'GL_MAX_TEXTURE_SIZE',
'GL_MAX_PIXEL_MAP_TABLE', 'GL_MAX_ATTRIB_STACK_DEPTH',
'GL_MAX_MODELVIEW_STACK_DEPTH', 'GL_MAX_NAME_STACK_DEPTH',
'GL_MAX_PROJECTION_STACK_DEPTH', 'GL_MAX_TEXTURE_STACK_DEPTH',
'GL_MAX_VIEWPORT_DIMS', 'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH',
'GL_SUBPIXEL_BITS', 'GL_INDEX_BITS', 'GL_RED_BITS', 'GL_GREEN_BITS',
'GL_BLUE_BITS', 'GL_ALPHA_BITS', 'GL_DEPTH_BITS', 'GL_STENCIL_BITS',
'GL_ACCUM_RED_BITS', 'GL_ACCUM_GREEN_BITS', 'GL_ACCUM_BLUE_BITS',
'GL_ACCUM_ALPHA_BITS', 'GL_NAME_STACK_DEPTH', 'GL_AUTO_NORMAL',
'GL_MAP1_COLOR_4', 'GL_MAP1_INDEX', 'GL_MAP1_NORMAL',
'GL_MAP1_TEXTURE_COORD_1', 'GL_MAP1_TEXTURE_COORD_2',
'GL_MAP1_TEXTURE_COORD_3', 'GL_MAP1_TEXTURE_COORD_4', 'GL_MAP1_VERTEX_3',
'GL_MAP1_VERTEX_4', 'GL_MAP2_COLOR_4', 'GL_MAP2_INDEX', 'GL_MAP2_NORMAL',
'GL_MAP2_TEXTURE_COORD_1', 'GL_MAP2_TEXTURE_COORD_2',
'GL_MAP2_TEXTURE_COORD_3', 'GL_MAP2_TEXTURE_COORD_4', 'GL_MAP2_VERTEX_3',
'GL_MAP2_VERTEX_4', 'GL_MAP1_GRID_DOMAIN', 'GL_MAP1_GRID_SEGMENTS',
'GL_MAP2_GRID_DOMAIN', 'GL_MAP2_GRID_SEGMENTS', 'GL_TEXTURE_1D',
'GL_TEXTURE_2D', 'GL_FEEDBACK_BUFFER_POINTER', 'GL_FEEDBACK_BUFFER_SIZE',
'GL_FEEDBACK_BUFFER_TYPE', 'GL_SELECTION_BUFFER_POINTER',
'GL_SELECTION_BUFFER_SIZE', 'GL_POLYGON_OFFSET_UNITS',
'GL_POLYGON_OFFSET_POINT', 'GL_POLYGON_OFFSET_LINE', 'GL_POLYGON_OFFSET_FILL',
'GL_POLYGON_OFFSET_FACTOR', 'GL_TEXTURE_BINDING_1D', 'GL_TEXTURE_BINDING_2D',
'GL_TEXTURE_BINDING_3D', 'GL_VERTEX_ARRAY', 'GL_NORMAL_ARRAY',
'GL_COLOR_ARRAY', 'GL_INDEX_ARRAY', 'GL_TEXTURE_COORD_ARRAY',
'GL_EDGE_FLAG_ARRAY', 'GL_VERTEX_ARRAY_SIZE', 'GL_VERTEX_ARRAY_TYPE',
'GL_VERTEX_ARRAY_STRIDE', 'GL_NORMAL_ARRAY_TYPE', 'GL_NORMAL_ARRAY_STRIDE',
'GL_COLOR_ARRAY_SIZE', 'GL_COLOR_ARRAY_TYPE', 'GL_COLOR_ARRAY_STRIDE',
'GL_INDEX_ARRAY_TYPE', 'GL_INDEX_ARRAY_STRIDE', 'GL_TEXTURE_COORD_ARRAY_SIZE',
'GL_TEXTURE_COORD_ARRAY_TYPE', 'GL_TEXTURE_COORD_ARRAY_STRIDE',
'GL_EDGE_FLAG_ARRAY_STRIDE', 'GL_TEXTURE_WIDTH', 'GL_TEXTURE_HEIGHT',
'GL_TEXTURE_INTERNAL_FORMAT', 'GL_TEXTURE_COMPONENTS',
'GL_TEXTURE_BORDER_COLOR', 'GL_TEXTURE_BORDER', 'GL_TEXTURE_RED_SIZE',
'GL_TEXTURE_GREEN_SIZE', 'GL_TEXTURE_BLUE_SIZE', 'GL_TEXTURE_ALPHA_SIZE',
'GL_TEXTURE_LUMINANCE_SIZE', 'GL_TEXTURE_INTENSITY_SIZE',
'GL_TEXTURE_PRIORITY', 'GL_TEXTURE_RESIDENT', 'GL_DONT_CARE', 'GL_FASTEST',
'GL_NICEST', 'GL_AMBIENT', 'GL_DIFFUSE', 'GL_SPECULAR', 'GL_POSITION',
'GL_SPOT_DIRECTION', 'GL_SPOT_EXPONENT', 'GL_SPOT_CUTOFF',
'GL_CONSTANT_ATTENUATION', 'GL_LINEAR_ATTENUATION',
'GL_QUADRATIC_ATTENUATION', 'GL_COMPILE', 'GL_COMPILE_AND_EXECUTE', 'GL_BYTE',
'GL_UNSIGNED_BYTE', 'GL_SHORT', 'GL_UNSIGNED_SHORT', 'GL_INT',
'GL_UNSIGNED_INT', 'GL_FLOAT', 'GL_2_BYTES', 'GL_3_BYTES', 'GL_4_BYTES',
'GL_DOUBLE', 'GL_DOUBLE_EXT', 'GL_CLEAR', 'GL_AND', 'GL_AND_REVERSE',
'GL_COPY', 'GL_AND_INVERTED', 'GL_NOOP', 'GL_XOR', 'GL_OR', 'GL_NOR',
'GL_EQUIV', 'GL_INVERT', 'GL_OR_REVERSE', 'GL_COPY_INVERTED',
'GL_OR_INVERTED', 'GL_NAND', 'GL_SET', 'GL_EMISSION', 'GL_SHININESS',
'GL_AMBIENT_AND_DIFFUSE', 'GL_COLOR_INDEXES', 'GL_MODELVIEW', 'GL_PROJECTION',
'GL_TEXTURE', 'GL_COLOR', 'GL_DEPTH', 'GL_STENCIL', 'GL_COLOR_INDEX',
'GL_STENCIL_INDEX', 'GL_DEPTH_COMPONENT', 'GL_RED', 'GL_GREEN', 'GL_BLUE',
'GL_ALPHA', 'GL_RGB', 'GL_RGBA', 'GL_LUMINANCE', 'GL_LUMINANCE_ALPHA',
'GL_BITMAP', 'GL_POINT', 'GL_LINE', 'GL_FILL', 'GL_RENDER', 'GL_FEEDBACK',
'GL_SELECT', 'GL_FLAT', 'GL_SMOOTH', 'GL_KEEP', 'GL_REPLACE', 'GL_INCR',
'GL_DECR', 'GL_VENDOR', 'GL_RENDERER', 'GL_VERSION', 'GL_EXTENSIONS', 'GL_S',
'GL_T', 'GL_R', 'GL_Q', 'GL_MODULATE', 'GL_DECAL', 'GL_TEXTURE_ENV_MODE',
'GL_TEXTURE_ENV_COLOR', 'GL_TEXTURE_ENV', 'GL_EYE_LINEAR', 'GL_OBJECT_LINEAR',
'GL_SPHERE_MAP', 'GL_TEXTURE_GEN_MODE', 'GL_OBJECT_PLANE', 'GL_EYE_PLANE',
'GL_NEAREST', 'GL_LINEAR', 'GL_NEAREST_MIPMAP_NEAREST',
'GL_LINEAR_MIPMAP_NEAREST', 'GL_NEAREST_MIPMAP_LINEAR',
'GL_LINEAR_MIPMAP_LINEAR', 'GL_TEXTURE_MAG_FILTER', 'GL_TEXTURE_MIN_FILTER',
'GL_TEXTURE_WRAP_S', 'GL_TEXTURE_WRAP_T', 'GL_PROXY_TEXTURE_1D',
'GL_PROXY_TEXTURE_2D', 'GL_CLAMP', 'GL_REPEAT', 'GL_R3_G3_B2', 'GL_ALPHA4',
'GL_ALPHA8', 'GL_ALPHA12', 'GL_ALPHA16', 'GL_LUMINANCE4', 'GL_LUMINANCE8',
'GL_LUMINANCE12', 'GL_LUMINANCE16', 'GL_LUMINANCE4_ALPHA4',
'GL_LUMINANCE6_ALPHA2', 'GL_LUMINANCE8_ALPHA8', 'GL_LUMINANCE12_ALPHA4',
'GL_LUMINANCE12_ALPHA12', 'GL_LUMINANCE16_ALPHA16', 'GL_INTENSITY',
'GL_INTENSITY4', 'GL_INTENSITY8', 'GL_INTENSITY12', 'GL_INTENSITY16',
'GL_RGB4', 'GL_RGB5', 'GL_RGB8', 'GL_RGB10', 'GL_RGB12', 'GL_RGB16',
'GL_RGBA2', 'GL_RGBA4', 'GL_RGB5_A1', 'GL_RGBA8', 'GL_RGB10_A2', 'GL_RGBA12',
'GL_RGBA16', 'GL_V2F', 'GL_V3F', 'GL_C4UB_V2F', 'GL_C4UB_V3F', 'GL_C3F_V3F',
'GL_N3F_V3F', 'GL_C4F_N3F_V3F', 'GL_T2F_V3F', 'GL_T4F_V4F', 'GL_T2F_C4UB_V3F',
'GL_T2F_C3F_V3F', 'GL_T2F_N3F_V3F', 'GL_T2F_C4F_N3F_V3F',
'GL_T4F_C4F_N3F_V4F', 'GL_CLIP_PLANE0', 'GL_CLIP_PLANE1', 'GL_CLIP_PLANE2',
'GL_CLIP_PLANE3', 'GL_CLIP_PLANE4', 'GL_CLIP_PLANE5', 'GL_LIGHT0',
'GL_LIGHT1', 'GL_LIGHT2', 'GL_LIGHT3', 'GL_LIGHT4', 'GL_LIGHT5', 'GL_LIGHT6',
'GL_LIGHT7', 'GL_ABGR_EXT', 'GL_FUNC_SUBTRACT_EXT',
'GL_FUNC_REVERSE_SUBTRACT_EXT', 'GL_UNSIGNED_BYTE_3_3_2_EXT',
'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 'GL_UNSIGNED_SHORT_5_5_5_1_EXT',
'GL_UNSIGNED_INT_8_8_8_8_EXT', 'GL_UNSIGNED_INT_10_10_10_2_EXT',
'GL_PACK_SKIP_IMAGES', 'GL_PACK_IMAGE_HEIGHT', 'GL_UNPACK_SKIP_IMAGES',
'GL_UNPACK_IMAGE_HEIGHT', 'GL_TEXTURE_3D', 'GL_PROXY_TEXTURE_3D',
'GL_TEXTURE_DEPTH', 'GL_TEXTURE_WRAP_R', 'GL_MAX_3D_TEXTURE_SIZE', 'GL_BGR',
'GL_BGRA', 'GL_UNSIGNED_BYTE_3_3_2', 'GL_UNSIGNED_BYTE_2_3_3_REV',
'GL_UNSIGNED_SHORT_5_6_5', 'GL_UNSIGNED_SHORT_5_6_5_REV',
'GL_UNSIGNED_SHORT_4_4_4_4', 'GL_UNSIGNED_SHORT_4_4_4_4_REV',
'GL_UNSIGNED_SHORT_5_5_5_1', 'GL_UNSIGNED_SHORT_1_5_5_5_REV',
'GL_UNSIGNED_INT_8_8_8_8', 'GL_UNSIGNED_INT_8_8_8_8_REV',
'GL_UNSIGNED_INT_10_10_10_2', 'GL_UNSIGNED_INT_2_10_10_10_REV',
'GL_RESCALE_NORMAL', 'GL_LIGHT_MODEL_COLOR_CONTROL', 'GL_SINGLE_COLOR',
'GL_SEPARATE_SPECULAR_COLOR', 'GL_CLAMP_TO_EDGE', 'GL_TEXTURE_MIN_LOD',
'GL_TEXTURE_MAX_LOD', 'GL_TEXTURE_BASE_LEVEL', 'GL_TEXTURE_MAX_LEVEL',
'GL_MAX_ELEMENTS_VERTICES', 'GL_MAX_ELEMENTS_INDICES',
'GL_ALIASED_POINT_SIZE_RANGE', 'GL_ALIASED_LINE_WIDTH_RANGE',
'GL_ACTIVE_TEXTURE', 'GL_CLIENT_ACTIVE_TEXTURE', 'GL_MAX_TEXTURE_UNITS',
'GL_TEXTURE0', 'GL_TEXTURE1', 'GL_TEXTURE2', 'GL_TEXTURE3', 'GL_TEXTURE4',
'GL_TEXTURE5', 'GL_TEXTURE6', 'GL_TEXTURE7', 'GL_TEXTURE8', 'GL_TEXTURE9',
'GL_TEXTURE10', 'GL_TEXTURE11', 'GL_TEXTURE12', 'GL_TEXTURE13',
'GL_TEXTURE14', 'GL_TEXTURE15', 'GL_TEXTURE16', 'GL_TEXTURE17',
'GL_TEXTURE18', 'GL_TEXTURE19', 'GL_TEXTURE20', 'GL_TEXTURE21',
'GL_TEXTURE22', 'GL_TEXTURE23', 'GL_TEXTURE24', 'GL_TEXTURE25',
'GL_TEXTURE26', 'GL_TEXTURE27', 'GL_TEXTURE28', 'GL_TEXTURE29',
'GL_TEXTURE30', 'GL_TEXTURE31', 'GL_NORMAL_MAP', 'GL_REFLECTION_MAP',
'GL_TEXTURE_CUBE_MAP', 'GL_TEXTURE_BINDING_CUBE_MAP',
'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z',
'GL_PROXY_TEXTURE_CUBE_MAP', 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 'GL_COMBINE',
'GL_COMBINE_RGB', 'GL_COMBINE_ALPHA', 'GL_RGB_SCALE', 'GL_ADD_SIGNED',
'GL_INTERPOLATE', 'GL_CONSTANT', 'GL_PRIMARY_COLOR', 'GL_PREVIOUS',
'GL_SOURCE0_RGB', 'GL_SOURCE1_RGB', 'GL_SOURCE2_RGB', 'GL_SOURCE0_ALPHA',
'GL_SOURCE1_ALPHA', 'GL_SOURCE2_ALPHA', 'GL_OPERAND0_RGB', 'GL_OPERAND1_RGB',
'GL_OPERAND2_RGB', 'GL_OPERAND0_ALPHA', 'GL_OPERAND1_ALPHA',
'GL_OPERAND2_ALPHA', 'GL_SUBTRACT', 'GL_TRANSPOSE_MODELVIEW_MATRIX',
'GL_TRANSPOSE_PROJECTION_MATRIX', 'GL_TRANSPOSE_TEXTURE_MATRIX',
'GL_TRANSPOSE_COLOR_MATRIX', 'GL_COMPRESSED_ALPHA', 'GL_COMPRESSED_LUMINANCE',
'GL_COMPRESSED_LUMINANCE_ALPHA', 'GL_COMPRESSED_INTENSITY',
'GL_COMPRESSED_RGB', 'GL_COMPRESSED_RGBA', 'GL_TEXTURE_COMPRESSION_HINT',
'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 'GL_TEXTURE_COMPRESSED',
'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 'GL_COMPRESSED_TEXTURE_FORMATS',
'GL_DOT3_RGB', 'GL_DOT3_RGBA', 'GL_CLAMP_TO_BORDER', 'GL_MULTISAMPLE',
'GL_SAMPLE_ALPHA_TO_COVERAGE', 'GL_SAMPLE_ALPHA_TO_ONE', 'GL_SAMPLE_COVERAGE',
'GL_SAMPLE_BUFFERS', 'GL_SAMPLES', 'GL_SAMPLE_COVERAGE_VALUE',
'GL_SAMPLE_COVERAGE_INVERT', 'GL_MULTISAMPLE_BIT', 'GL_VERTEX_ARRAY_EXT',
'GL_NORMAL_ARRAY_EXT', 'GL_COLOR_ARRAY_EXT', 'GL_INDEX_ARRAY_EXT',
'GL_TEXTURE_COORD_ARRAY_EXT', 'GL_EDGE_FLAG_ARRAY_EXT',
'GL_VERTEX_ARRAY_SIZE_EXT', 'GL_VERTEX_ARRAY_TYPE_EXT',
'GL_VERTEX_ARRAY_STRIDE_EXT', 'GL_VERTEX_ARRAY_COUNT_EXT',
'GL_NORMAL_ARRAY_TYPE_EXT', 'GL_NORMAL_ARRAY_STRIDE_EXT',
'GL_NORMAL_ARRAY_COUNT_EXT', 'GL_COLOR_ARRAY_SIZE_EXT',
'GL_COLOR_ARRAY_TYPE_EXT', 'GL_COLOR_ARRAY_STRIDE_EXT',
'GL_COLOR_ARRAY_COUNT_EXT', 'GL_INDEX_ARRAY_TYPE_EXT',
'GL_INDEX_ARRAY_STRIDE_EXT', 'GL_INDEX_ARRAY_COUNT_EXT',
'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT',
'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT',
'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 'GL_EDGE_FLAG_ARRAY_COUNT_EXT',
'GL_VERTEX_ARRAY_POINTER_EXT', 'GL_NORMAL_ARRAY_POINTER_EXT',
'GL_COLOR_ARRAY_POINTER_EXT', 'GL_INDEX_ARRAY_POINTER_EXT',
'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 'GL_EDGE_FLAG_ARRAY_POINTER_EXT',
'GL_TEXTURE_MIN_LOD_SGIS', 'GL_TEXTURE_MAX_LOD_SGIS',
'GL_TEXTURE_BASE_LEVEL_SGIS', 'GL_TEXTURE_MAX_LEVEL_SGIS',
'GL_SHARED_TEXTURE_PALETTE_EXT', 'GL_RESCALE_NORMAL_EXT',
'GL_TEXTURE_COMPARE_SGIX', 'GL_TEXTURE_COMPARE_OPERATOR_SGIX',
'GL_TEXTURE_LEQUAL_R_SGIX', 'GL_TEXTURE_GEQUAL_R_SGIX',
'GL_DEPTH_COMPONENT16_SGIX', 'GL_DEPTH_COMPONENT24_SGIX',
'GL_DEPTH_COMPONENT32_SGIX', 'GL_GENERATE_MIPMAP_SGIS',
'GL_GENERATE_MIPMAP_HINT_SGIS', 'GL_POINT_SIZE_MIN', 'GL_POINT_SIZE_MAX',
'GL_POINT_FADE_THRESHOLD_SIZE', 'GL_POINT_DISTANCE_ATTENUATION',
'GL_FOG_COORDINATE_SOURCE', 'GL_FOG_COORDINATE', 'GL_FRAGMENT_DEPTH',
'GL_CURRENT_FOG_COORDINATE', 'GL_FOG_COORDINATE_ARRAY_TYPE',
'GL_FOG_COORDINATE_ARRAY_STRIDE', 'GL_FOG_COORDINATE_ARRAY_POINTER',
'GL_FOG_COORDINATE_ARRAY', 'GL_COLOR_SUM', 'GL_CURRENT_SECONDARY_COLOR',
'GL_SECONDARY_COLOR_ARRAY_SIZE', 'GL_SECONDARY_COLOR_ARRAY_TYPE',
'GL_SECONDARY_COLOR_ARRAY_STRIDE', 'GL_SECONDARY_COLOR_ARRAY_POINTER',
'GL_SECONDARY_COLOR_ARRAY', 'GL_INCR_WRAP', 'GL_DECR_WRAP',
'GL_MAX_TEXTURE_LOD_BIAS', 'GL_TEXTURE_FILTER_CONTROL', 'GL_TEXTURE_LOD_BIAS',
'GL_GENERATE_MIPMAP', 'GL_GENERATE_MIPMAP_HINT', 'GL_BLEND_DST_RGB',
'GL_BLEND_SRC_RGB', 'GL_BLEND_DST_ALPHA', 'GL_BLEND_SRC_ALPHA',
'GL_MIRRORED_REPEAT', 'GL_DEPTH_COMPONENT16', 'GL_DEPTH_COMPONENT24',
'GL_DEPTH_COMPONENT32', 'GL_TEXTURE_DEPTH_SIZE', 'GL_DEPTH_TEXTURE_MODE',
'GL_TEXTURE_COMPARE_MODE', 'GL_TEXTURE_COMPARE_FUNC',
'GL_COMPARE_R_TO_TEXTURE', 'glAccum', 'glAlphaFunc', 'glAreTexturesResident',
'glArrayElement', 'glBegin', 'glBindTexture', 'glBitmap', 'glBlendFunc',
'glCallList', 'glCallLists', 'glClear', 'glClearAccum', 'glClearColor',
'glClearDepth', 'glClearIndex', 'glClearStencil', 'glClipPlane', 'glColor3b',
'glColor3bv', 'glColor3d', 'glColor3dv', 'glColor3f', 'glColor3fv',
'glColor3i', 'glColor3iv', 'glColor3s', 'glColor3sv', 'glColor3ub',
'glColor3ubv', 'glColor3ui', 'glColor3uiv', 'glColor3us', 'glColor3usv',
'glColor4b', 'glColor4bv', 'glColor4d', 'glColor4dv', 'glColor4f',
'glColor4fv', 'glColor4i', 'glColor4iv', 'glColor4s', 'glColor4sv',
'glColor4ub', 'glColor4ubv', 'glColor4ui', 'glColor4uiv', 'glColor4us',
'glColor4usv', 'glColorMask', 'glColorMaterial', 'glColorPointer',
'glCopyPixels', 'glCopyTexImage1D', 'glCopyTexImage2D', 'glCopyTexSubImage1D',
'glCopyTexSubImage2D', 'glCullFace', 'glDeleteLists', 'glDeleteTextures',
'glDepthFunc', 'glDepthMask', 'glDepthRange', 'glDisable',
'glDisableClientState', 'glDrawArrays', 'glDrawBuffer', 'glDrawElements',
'glDrawPixels', 'glEdgeFlag', 'glEdgeFlagPointer', 'glEdgeFlagv', 'glEnable',
'glEnableClientState', 'glEnd', 'glEndList', 'glEvalCoord1d',
'glEvalCoord1dv', 'glEvalCoord1f', 'glEvalCoord1fv', 'glEvalCoord2d',
'glEvalCoord2dv', 'glEvalCoord2f', 'glEvalCoord2fv', 'glEvalMesh1',
'glEvalMesh2', 'glEvalPoint1', 'glEvalPoint2', 'glFeedbackBuffer', 'glFinish',
'glFlush', 'glFogf', 'glFogfv', 'glFogi', 'glFogiv', 'glFrontFace',
'glFrustum', 'glGenLists', 'glGenTextures', 'glGetBooleanv', 'glGetClipPlane',
'glGetDoublev', 'glGetError', 'glGetFloatv', 'glGetIntegerv', 'glGetLightfv',
'glGetLightiv', 'glGetMapdv', 'glGetMapfv', 'glGetMapiv', 'glGetMaterialfv',
'glGetMaterialiv', 'glGetPixelMapfv', 'glGetPixelMapuiv', 'glGetPixelMapusv',
'glGetPointerv', 'glGetPolygonStipple', 'glGetString', 'glGetTexEnvfv',
'glGetTexEnviv', 'glGetTexGendv', 'glGetTexGenfv', 'glGetTexGeniv',
'glGetTexImage', 'glGetTexLevelParameterfv', 'glGetTexLevelParameteriv',
'glGetTexParameterfv', 'glGetTexParameteriv', 'glHint', 'glIndexMask',
'glIndexPointer', 'glIndexd', 'glIndexdv', 'glIndexf', 'glIndexfv',
'glIndexi', 'glIndexiv', 'glIndexs', 'glIndexsv', 'glIndexub', 'glIndexubv',
'glInitNames', 'glInterleavedArrays', 'glIsEnabled', 'glIsList',
'glIsTexture', 'glLightModelf', 'glLightModelfv', 'glLightModeli',
'glLightModeliv', 'glLightf', 'glLightfv', 'glLighti', 'glLightiv',
'glLineStipple', 'glLineWidth', 'glListBase', 'glLoadIdentity',
'glLoadMatrixd', 'glLoadMatrixf', 'glLoadName', 'glLogicOp', 'glMap1d',
'glMap1f', 'glMap2d', 'glMap2f', 'glMapGrid1d', 'glMapGrid1f', 'glMapGrid2d',
'glMapGrid2f', 'glMaterialf', 'glMaterialfv', 'glMateriali', 'glMaterialiv',
'glMatrixMode', 'glMultMatrixd', 'glMultMatrixf', 'glNewList', 'glNormal3b',
'glNormal3bv', 'glNormal3d', 'glNormal3dv', 'glNormal3f', 'glNormal3fv',
'glNormal3i', 'glNormal3iv', 'glNormal3s', 'glNormal3sv', 'glNormalPointer',
'glOrtho', 'glPassThrough', 'glPixelMapfv', 'glPixelMapuiv', 'glPixelMapusv',
'glPixelStoref', 'glPixelStorei', 'glPixelTransferf', 'glPixelTransferi',
'glPixelZoom', 'glPointSize', 'glPolygonMode', 'glPolygonOffset',
'glPolygonStipple', 'glPopAttrib', 'glPopClientAttrib', 'glPopMatrix',
'glPopName', 'glPrioritizeTextures', 'glPushAttrib', 'glPushClientAttrib',
'glPushMatrix', 'glPushName', 'glRasterPos2d', 'glRasterPos2dv',
'glRasterPos2f', 'glRasterPos2fv', 'glRasterPos2i', 'glRasterPos2iv',
'glRasterPos2s', 'glRasterPos2sv', 'glRasterPos3d', 'glRasterPos3dv',
'glRasterPos3f', 'glRasterPos3fv', 'glRasterPos3i', 'glRasterPos3iv',
'glRasterPos3s', 'glRasterPos3sv', 'glRasterPos4d', 'glRasterPos4dv',
'glRasterPos4f', 'glRasterPos4fv', 'glRasterPos4i', 'glRasterPos4iv',
'glRasterPos4s', 'glRasterPos4sv', 'glReadBuffer', 'glReadPixels', 'glRectd',
'glRectdv', 'glRectf', 'glRectfv', 'glRecti', 'glRectiv', 'glRects',
'glRectsv', 'glRenderMode', 'glRotated', 'glRotatef', 'glScaled', 'glScalef',
'glScissor', 'glSelectBuffer', 'glShadeModel', 'glStencilFunc',
'glStencilMask', 'glStencilOp', 'glTexCoord1d', 'glTexCoord1dv',
'glTexCoord1f', 'glTexCoord1fv', 'glTexCoord1i', 'glTexCoord1iv',
'glTexCoord1s', 'glTexCoord1sv', 'glTexCoord2d', 'glTexCoord2dv',
'glTexCoord2f', 'glTexCoord2fv', 'glTexCoord2i', 'glTexCoord2iv',
'glTexCoord2s', 'glTexCoord2sv', 'glTexCoord3d', 'glTexCoord3dv',
'glTexCoord3f', 'glTexCoord3fv', 'glTexCoord3i', 'glTexCoord3iv',
'glTexCoord3s', 'glTexCoord3sv', 'glTexCoord4d', 'glTexCoord4dv',
'glTexCoord4f', 'glTexCoord4fv', 'glTexCoord4i', 'glTexCoord4iv',
'glTexCoord4s', 'glTexCoord4sv', 'glTexCoordPointer', 'glTexEnvf',
'glTexEnvfv', 'glTexEnvi', 'glTexEnviv', 'glTexGend', 'glTexGendv',
'glTexGenf', 'glTexGenfv', 'glTexGeni', 'glTexGeniv', 'glTexImage1D',
'glTexImage2D', 'glTexParameterf', 'glTexParameterfv', 'glTexParameteri',
'glTexParameteriv', 'glTexSubImage1D', 'glTexSubImage2D', 'glTranslated',
'glTranslatef', 'glVertex2d', 'glVertex2dv', 'glVertex2f', 'glVertex2fv',
'glVertex2i', 'glVertex2iv', 'glVertex2s', 'glVertex2sv', 'glVertex3d',
'glVertex3dv', 'glVertex3f', 'glVertex3fv', 'glVertex3i', 'glVertex3iv',
'glVertex3s', 'glVertex3sv', 'glVertex4d', 'glVertex4dv', 'glVertex4f',
'glVertex4fv', 'glVertex4i', 'glVertex4iv', 'glVertex4s', 'glVertex4sv',
'glVertexPointer', 'glViewport']
# END GENERATED CONTENT (do not edit above this line)



